<?php
// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

class SFFM_Admin_Notice {

    public function __construct() {
        add_action('admin_init', array($this, 'welcome_init'));
        add_action('admin_notices', array($this, 'admin_notice_content'));
    }

    /**
     * Handle a click on the dismiss button
     *
     * @return void
     */
    public function welcome_init() {
        if (!get_option('sffm_first_activation')) {
            update_option('sffm_first_activation', time());
        }

        if (isset($_GET['sffm-hide-notice'], $_GET['sffm_notice_nonce'])) {
            $notice = sanitize_key($_GET['sffm-hide-notice']);
            if (check_admin_referer($notice, 'sffm_notice_nonce')) {
                self::dismiss($notice);
                wp_safe_redirect(remove_query_arg(array('sffm-hide-notice', 'sffm_notice_nonce'), wp_get_referer()));
                exit;
            }
        }
    }

    /**
     * Displays a notice asking for a review
     *
     * @return void
     */
    private function review_notice() {
        ?>
        <div class="sffm-notice notice notice-info">
            <?php $this->dismiss_button('review'); ?>
            <div class="sffm-notice-icon">
                <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 37.6 37.6" style="fill:#72aee6">
                    <g>
                        <g>
                            <path d="M11.5 1.5a19.69 19.69 0 0 0-6 4 16.23 16.23 0 0 0-4 6 18.51 18.51 0 0 0 0 14.6A19 19 0 0 0 3.8 30v-.1l.1-.3.1-.4V29a12.27 12.27 0 0 1-1.7-3.2 18.2 18.2 0 0 1 0-14 16.1 16.1 0 0 1 3.9-5.7 19.94 19.94 0 0 1 5.7-3.9 18.2 18.2 0 0 1 14 0 3 3 0 0 1 .8.4l.9-.2.3-.1a9.82 9.82 0 0 0-1.8-.8A18.35 18.35 0 0 0 18.8 0a18 18 0 0 0-7.3 1.5Z" />
                            <path d="M30.2 30a5.17 5.17 0 0 0 .8-1.9l1.2-6.9a4 4 0 0 0-.1-1.9 5.07 5.07 0 0 0-.9-1.6 6.45 6.45 0 0 0-1.6-1.1 5.38 5.38 0 0 0-2.2-.4H15.7l.5-3.2 9-1.7-.5 2.9h8.7l1-6a4.07 4.07 0 0 0-.2-2.2 3.71 3.71 0 0 0-1.3-1.7 5.12 5.12 0 0 0-2.1-1 5.7 5.7 0 0 0-2.6 0L13.3 6.1a7.34 7.34 0 0 0-3.5 1.8A5.24 5.24 0 0 0 8 11l-1.2 7a4 4 0 0 0 .1 1.9 5.07 5.07 0 0 0 .9 1.6 6.45 6.45 0 0 0 1.6 1.1 5.09 5.09 0 0 0 2.2.4h11.5l-.4 2.5H5.5L5.1 28l-.9 5h20.1a5.87 5.87 0 0 0 2.3-.4 6.44 6.44 0 0 0 2-1.1 4.63 4.63 0 0 0 1.6-1.5Z" />
                            <path d="M36.1 11.5a18.51 18.51 0 0 1 0 14.6 19.69 19.69 0 0 1-4 6 17.55 17.55 0 0 1-6 4 18.51 18.51 0 0 1-14.6 0A22.18 22.18 0 0 1 7.8 34h1.4a17.07 17.07 0 0 0 2.7 1.4 18.2 18.2 0 0 0 14 0 16.1 16.1 0 0 0 5.7-3.9 19.94 19.94 0 0 0 3.9-5.7 18.2 18.2 0 0 0 0-14c-.1-.3-.3-.7-.4-1l.2-1.3a16.67 16.67 0 0 0 .8 2Z" />
                        </g>
                    </g>
                </svg>
            </div>
            <div class="sffm-notice-info">
                <p>
                    <?php
                    printf(
                        /* translators: %1$s is link start tag, %2$s is link end tag. */
                        esc_html__('Great to see that you have been using Super Floating and Flying Menu for some time. We hope you love it, and we would really appreciate it if you would %1$sgive us a 5 stars rating%2$s and spread your words to the world.', 'super-floating-flying-menu'), '<a target="_blank" href="https://codecanyon.net/item/super-floating-and-fly-menu-sticky-side-one-page-navigator-offcanvas-menu-plugin-for-wordpress/reviews/30485289">', '</a>'
                    );
                    ?>
                </p>
                <a target="_blank" class="button button-primary button-large" href="https://codecanyon.net/item/super-floating-and-fly-menu-sticky-side-one-page-navigator-offcanvas-menu-plugin-for-wordpress/reviews/30485289"><span class="dashicons dashicons-thumbs-up"></span><?php echo esc_html__('Yes, of course', 'super-floating-flying-menu') ?></a> &nbsp;
                <a class="button button-large" href="<?php echo esc_url(wp_nonce_url(add_query_arg('sffm-hide-notice', 'review'), 'review', 'sffm_notice_nonce')); ?>"><span class="dashicons dashicons-yes"></span><?php echo esc_html__('I have already rated', 'super-floating-flying-menu') ?></a>
            </div>
        </div>
        <?php
    }

    /**
     * Has a notice been dismissed?
     *
     * @param string $notice Notice name
     * @return bool
     */
    public static function is_dismissed($notice) {
        $dismissed = get_option('sffm_dismissed_notices', array());

        // Handle legacy user meta
        $dismissed_meta = get_user_meta(get_current_user_id(), 'sffm_dismissed_notices', true);
        if (is_array($dismissed_meta)) {
            if (array_diff($dismissed_meta, $dismissed)) {
                $dismissed = array_merge($dismissed, $dismissed_meta);
                update_option('sffm_dismissed_notices', $dismissed);
            }
            if (!is_multisite()) {
                // Don't delete on multisite to avoid the notices to appear in other sites.
                delete_user_meta(get_current_user_id(), 'sffm_dismissed_notices');
            }
        }

        return in_array($notice, $dismissed);
    }

    /**
     * Displays a dismiss button
     *
     * @param string $name Notice name
     * @return void
     */
    public function dismiss_button($name) {
        printf('<a class="notice-dismiss" href="%s"><span class="screen-reader-text">%s</span></a>', esc_url(wp_nonce_url(add_query_arg('sffm-hide-notice', $name), $name, 'sffm_notice_nonce')), esc_html__('Dismiss this notice.', 'super-floating-flying-menu')
        );
    }

    /**
     * Stores a dismissed notice in database
     *
     * @param string $notice
     * @return void
     */
    public static function dismiss($notice) {
        $dismissed = get_option('sffm_dismissed_notices', array());

        if (!in_array($notice, $dismissed)) {
            $dismissed[] = $notice;
            update_option('sffm_dismissed_notices', array_unique($dismissed));
        }
    }

    /** Welcome Message Notification */
    public function admin_notice_content() {
        if (!$this->is_dismissed('review') && !empty(get_option('sffm_first_activation')) && time() > get_option('sffm_first_activation') + 15 * DAY_IN_SECONDS) {
            $this->review_notice();
        }
    }

}

new SFFM_Admin_Notice();
