(function ($, elementor) {
    "use strict";
    var SFFMElements = {

        init: function () {

            var widgets = {
                'sffm-multi-level-menu.default': SFFMElements.multiLevelMenu,
                'sffm-multi-level-breadcrumb-menu.default': SFFMElements.multiLevelMenuOne,
                'sffm-hover-menu.default': SFFMElements.hoverMenu,
                'sffm-close-menu-button.default': SFFMElements.closeMenuPanel
            };

            $.each(widgets, function (widget, callback) {
                elementor.hooks.addAction('frontend/element_ready/' + widget, callback);
            });

        },

        hoverMenu: function ($scope) {
            var $target = $scope.find('.sffm-el-menu');
            if ($target.hasClass('sffm-el-menu--style2')) {
                $target.find('.sffm-el-menu-item').each(function () {
                    new SffmMenuHoverStyle2Item($(this));
                });
            } else if ($target.hasClass('sffm-el-menu--style3')) {
                $target.find('.sffm-el-menu-item').each(function () {
                    new SffmMenuHoverStyle3Item($(this));
                });
            } else if ($target.hasClass('sffm-el-menu--style4')) {
                $target.find('.sffm-el-menu-item').each(function () {
                    new SffmMenuHoverStyle4Item($(this));
                });
            } else if ($target.hasClass('sffm-el-menu--style5')) {
                $target.find('.sffm-el-menu-item').each(function () {
                    new SffmMenuHoverStyle5Item($(this));
                });
            } else if ($target.hasClass('sffm-el-menu--style7')) {
                $target.find('.sffm-el-menu-item').each(function () {
                    new SffmMenuHoverStyle7Item($(this));
                });
            } else if ($target.hasClass('sffm-el-menu--style8')) {
                $target.find('.sffm-el-menu-item').each(function () {
                    new SffmMenuHoverStyle8Item($(this));
                });
            }
        },

        multiLevelMenu: function ($scope) {
            var $target = $scope.find('.sffm-menu-container'),
                bckBtnTxt = $target.data('back-button-text'),
                submenuIcon = $target.data('sub-menu-icon'),
                menuStyle = $target.data('menu-style');

            if (!$target.length) {
                return;
            }

            $.each($scope.find('.sffm-submenu-toggle'), function () {
                var self = $(this);
                self.html('<span class="' + submenuIcon + '"></span>');
            });

            $.each($scope.find('.sffm-back'), function () {
                var self = $(this);
                self.find('span').html(bckBtnTxt);
            });

            $target.sffmmenu({
                animationClasses: {classin: 'sffm-animate-in-' + menuStyle, classout: 'sffm-animate-out-' + menuStyle},
            });
        },

        multiLevelMenuOne: function ($scope) {
            var menuEl = $scope.find('.sffm-mlm-menu');

            if (menuEl.length > 0) {
                var settings = JSON.parse(menuEl.attr('data-settings'));
                $.each($scope.find('ul li'), function () {
                    var self = $(this);
                    if (self.children('ul').length > 0) {
                        if (self.children('a').attr('id')) {
                            self.children('a').attr('data-submenu', self.children('a').attr('id'));
                            self.children('ul').attr('data-menu', self.children('a').attr('id'));
                        }

                        self.children('a').append('<span class="' + settings.sub_menu_indicator + '"></span>');
                        $scope.find('.sffm-mlm-menu .sffm-mlm-wrap').append(self.children('ul'));
                    }
                });

                new MLMenu(menuEl[0], {
                    breadcrumbsCtrl: JSON.parse(settings.show_breadcrumb), // show breadcrumbs
                    initialBreadcrumb: settings.breadcrumb_text, // initial breadcrumb text
                    backCtrl: JSON.parse(settings.show_back_button), // show back button
                    backCtrlClass: settings.back_button_icon,
                    itemsDelayInterval: settings.item_delay_interval, // delay between each menu item sliding animation,
                    direction: settings.direction,
                });
            }
        },

        closeMenuPanel: function ($scope) {
            $scope.find('.sffm-menu-close').on('click', function () {
                var $wrap = $(this).closest('.sffm-flymenu-wrapper');
                $wrap.find('.sffm-flymenu-trigger').trigger('click');
                return false;
            });
        }

    };

    $(window).on('elementor/frontend/init', SFFMElements.init);
}(jQuery, window.elementorFrontend));