<?php

namespace SFFM;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

class SFFM_Multi_Level_Walker_Nav_Menu extends \Walker_Nav_Menu {

    function start_lvl(&$output, $depth = 0, $args = array()) {
        if (isset($args->item_spacing) && 'discard' === $args->item_spacing) {
            $t = '';
            $n = '';
        } else {
            $t = "\t";
            $n = "\n";
        }
        $indent = str_repeat($t, $depth);

        // Default class.
        $classes = array('sffm-submenu');

        $class_names = implode(' ', apply_filters('sffm_nav_menu_submenu_css_class', $classes, $args, $depth));
        $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

        $output .= "{$n}{$indent}<ul$class_names>{$n}";

        $output .= "{$n}{$indent}<li class='sffm-back sffm-menu-item'><a class='sffm-menu-item-link' href='#'><i class='mdi mdi-chevron-left'></i><span>" . esc_html__('Back', 'super-floating-flying-menu') . "</span></a></li>{$n}";
    }

    public function start_el(&$output, $data_object, $depth = 0, $args = null, $current_object_id = 0) {
        // Restores the more descriptive, specific name for use within this method.
        $menu_item = $data_object;

        if (isset($args->item_spacing) && 'discard' === $args->item_spacing) {
            $t = '';
            $n = '';
        } else {
            $t = "\t";
            $n = "\n";
        }
        $indent = ($depth) ? str_repeat($t, $depth) : '';

        $classes = array('sffm-menu-item');
        $classes[] = 'sffm-menu-item-' . $menu_item->ID;

        $args = apply_filters('sffm_nav_menu_item_args', $args, $menu_item, $depth);

        $class_names = implode(' ', apply_filters('sffm_nav_menu_css_class', array_filter($classes), $menu_item, $args, $depth));
        $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

        $id = apply_filters('sffm_nav_menu_item_id', 'sffm-menu-item-' . $menu_item->ID, $menu_item, $args, $depth);
        $id = $id ? ' id="' . esc_attr($id) . '"' : '';

        $output .= $indent . '<li' . $id . $class_names . '>';

        $atts = array();
        $atts['class'] = 'sffm-menu-item-link sffm-menu-item-link-depth-' . $depth . (($args->walker->has_children || !empty($push_menu_additional_content)) ? ' sffm-menu-item-link-has-children' : '');
        $atts['title'] = !empty($menu_item->attr_title) ? $menu_item->attr_title : '';
        $atts['target'] = !empty($menu_item->target) ? $menu_item->target : '';
        if ('_blank' === $menu_item->target && empty($menu_item->xfn)) {
            $atts['rel'] = 'noopener';
        } else {
            $atts['rel'] = $menu_item->xfn;
        }
        $atts['href'] = !empty($menu_item->url) ? $menu_item->url : '';
        $atts['aria-current'] = $menu_item->current ? 'page' : '';

        $atts = apply_filters('sffm_nav_menu_link_attributes', $atts, $menu_item, $args, $depth);

        $attributes = '';
        foreach ($atts as $attr => $value) {
            if (is_scalar($value) && '' !== $value && false !== $value) {
                $value = ('href' === $attr) ? esc_url($value) : esc_attr($value);
                $attributes .= ' ' . $attr . '="' . $value . '"';
            }
        }

        /** This filter is documented in wp-includes/post-template.php */
        $title = apply_filters('the_title', $menu_item->title, $menu_item->ID);

        $title = apply_filters('sffm_nav_menu_item_title', $title, $menu_item, $args, $depth);

        $item_output = $args->before;
        $item_output .= '<a' . $attributes . '>';
        $item_output .= '<span class="sffm-menu-link-items">';
        $item_output .= '<span class="sffm-menu-item-title">';
        $item_output .= $args->link_before . $title . $args->link_after;
        $item_output .= '</span>';

        if ($args->walker->has_children) {
            $item_output .= '<span class="sffm-submenu-toggle">';
            $item_output .= '</span>';
        }
        $item_output .= '</span>';
        $item_output .= '</a>';
        $item_output .= $args->after;

        $output .= apply_filters('sffm_walker_nav_menu_start_el', $item_output, $menu_item, $depth, $args);
    }

}

class SFFM_Multi_Level_Walker_Nav_Menu_One extends \Walker_Nav_Menu {

    public function start_lvl(&$output, $depth = 0, $args = null) {
        if (isset($args->item_spacing) && 'discard' === $args->item_spacing) {
            $t = '';
            $n = '';
        } else {
            $t = "\t";
            $n = "\n";
        }
        $indent = str_repeat($t, $depth);

        // Default class.
        $classes = array('sffm-mlm-level');

        $class_names = implode(' ', apply_filters('sffm_nav_menu_submenu_css_class', $classes, $args, $depth));
        $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

        $output .= "{$n}{$indent}<ul$class_names>{$n}";
    }

    public function start_el(&$output, $data_object, $depth = 0, $args = null, $current_object_id = 0) {
        // Restores the more descriptive, specific name for use within this method.
        $menu_item = $data_object;

        if (isset($args->item_spacing) && 'discard' === $args->item_spacing) {
            $t = '';
            $n = '';
        } else {
            $t = "\t";
            $n = "\n";
        }
        $indent = ($depth) ? str_repeat($t, $depth) : '';

        $classes = array();
        $classes[] = 'menu-item-' . $menu_item->ID;
        $classes[] = 'sffm-mlm-item';

        $args = apply_filters('sffm_nav_menu_item_args', $args, $menu_item, $depth);

        $class_names = implode(' ', apply_filters('sffm_nav_menu_css_class', array_filter($classes), $menu_item, $args, $depth));
        $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

        $id = apply_filters('sffm_nav_menu_item_id', 'menu-item-' . $menu_item->ID, $menu_item, $args, $depth);

        $output .= $indent . '<li' . $class_names . '>';

        $atts = array();
        $atts['id'] = 'sffm-' . $id;
        $atts['class'] = 'sffm-mlm-link';
        $atts['title'] = !empty($menu_item->attr_title) ? $menu_item->attr_title : '';
        $atts['target'] = !empty($menu_item->target) ? $menu_item->target : '';
        if ('_blank' === $menu_item->target && empty($menu_item->xfn)) {
            $atts['rel'] = 'noopener';
        } else {
            $atts['rel'] = $menu_item->xfn;
        }
        $atts['href'] = !empty($menu_item->url) ? $menu_item->url : '';
        $atts['aria-current'] = $menu_item->current ? 'page' : '';

        $atts = apply_filters('sffm_nav_menu_link_attributes', $atts, $menu_item, $args, $depth);

        $attributes = '';
        foreach ($atts as $attr => $value) {
            if (is_scalar($value) && '' !== $value && false !== $value) {
                $value = ('href' === $attr) ? esc_url($value) : esc_attr($value);
                $attributes .= ' ' . $attr . '="' . $value . '"';
            }
        }

        $title = apply_filters('the_title', $menu_item->title, $menu_item->ID);

        $title = apply_filters('sffm_nav_menu_item_title', $title, $menu_item, $args, $depth);

        $item_output = $args->before;
        $item_output .= '<a' . $attributes . '>';
        $item_output .= $args->link_before . '<span class="sffm-mlm-label">' . $title . '</span>' . $args->link_after;
        $item_output .= '</a>';
        $item_output .= $args->after;

        $output .= apply_filters('walker_nav_menu_start_el', $item_output, $menu_item, $depth, $args);
    }

}
