<?php

namespace SFFM\Modules\CloseMenuButton\Widgets;

// Elementor Classes
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class Close_Menu_Button extends Widget_Base {

    /** Widget Name */
    public function get_name() {
        return 'sffm-close-menu-button';
    }

    /** Widget Title */
    public function get_title() {
        return esc_html__('Close Menu Button', 'super-floating-flying-menu');
    }

    /** Icon */
    public function get_icon() {
        return 'eicon-navigation-vertical';
    }

    /** Category */
    public function get_categories() {
        return ['super-floating-flying-menu'];
    }

    /** Controls */
    protected function register_controls() {
        $this->start_controls_section(
            'content', [
                'label' => esc_html__('Close Button', 'super-floating-flying-menu'),
            ]
        );

        $this->add_control(
            'close_menu_title', [
                'label' => esc_html__('Close Menu Title', 'super-floating-flying-menu'),
                'type' => Controls_Manager::TEXT,
            ]
        );

        $this->add_control(
            'close_menu_icon', [
                'label' => esc_html__('Close Icon', 'super-floating-flying-menu'),
                'type' => Controls_Manager::ICONS,
                'skin' => 'inline',
                'label_block' => false,
                'default' => [
                    'value' => 'icofont-close-line',
                    'library' => 'sffm-icofont-icon',
                ],
            ]
        );

        $this->add_control(
            'icon_align', [
                'label' => esc_html__('Icon Position', 'super-floating-flying-menu'),
                'type' => Controls_Manager::SELECT,
                'default' => '1',
                'options' => [
                    '-1' => esc_html__('Before', 'super-floating-flying-menu'),
                    '1' => esc_html__('After', 'super-floating-flying-menu'),
                ],
                'condition' => [
                    'close_menu_title[value]!' => '',
                    'close_menu_icon[value]!' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close-icon' => 'order: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'icon_indent', [
                'label' => esc_html__('Icon Spacing', 'super-floating-flying-menu'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 50,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 6,
                ],
                'condition' => [
                    'close_menu_title[value]!' => '',
                    'close_menu_icon[value]!' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'align', [
                'label' => esc_html__('Alignment', 'super-floating-flying-menu'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'super-floating-flying-menu'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'super-floating-flying-menu'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'super-floating-flying-menu'),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__('Justified', 'super-floating-flying-menu'),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'selectors_dictionary' => [
                    'left' => 'justify-content: flex-start;flex-direction: row;',
                    'center' => 'justify-content: center;flex-direction: row;',
                    'right' => 'justify-content: flex-end;flex-direction: row;',
                    'justify' => 'flex-direction: column',
                ],
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button' => '{{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'style_section', [
                'label' => esc_html__('Close Button', 'super-floating-flying-menu'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'typography',
                'selector' => '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close',
                'condition' => [
                    'close_menu_title[value]!' => ''
                ],
            ]
        );

        $this->add_control(
            'icon_size', [
                'label' => esc_html__('Icon Size', 'super-floating-flying-menu'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 50,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 22,
                ],
                'condition' => [
                    'close_menu_title[value]' => '',
                    'close_menu_icon[value]!' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('tabs_button_style');

        $this->start_controls_tab(
            'tab_button_normal', [
                'label' => esc_html__('Normal', 'super-floating-flying-menu'),
            ]
        );

        $this->add_control(
            'button_text_color', [
                'label' => esc_html__('Text Color', 'super-floating-flying-menu'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close' => 'fill: {{VALUE}}; color: {{VALUE}};',
                ],
                'default' => '#FFFFFF'
            ]
        );

        $this->add_control(
            'button_background_color', [
                'label' => esc_html__('Background Color', 'super-floating-flying-menu'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close' => 'background-color: {{VALUE}};',
                ],
                'default' => '#000000'
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_button_hover', [
                'label' => esc_html__('Hover', 'super-floating-flying-menu'),
            ]
        );

        $this->add_control(
            'hover_color', [
                'label' => esc_html__('Text Color', 'super-floating-flying-menu'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close:hover, {{WRAPPER}} .sffm-menu-close-button .sffm-menu-close:focus' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close:hover svg, {{WRAPPER}} .sffm-menu-close-button .sffm-menu-close:focus svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'hover_button_background_color', [
                'label' => esc_html__('Background Color', 'super-floating-flying-menu'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close:hover, {{WRAPPER}} .sffm-menu-close-button .sffm-menu-close:focus' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_hover_border_color', [
                'label' => esc_html__('Border Color', 'super-floating-flying-menu'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'border_border!' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close:hover, {{WRAPPER}} .sffm-menu-close-button .sffm-menu-close:focus' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'hover_animation', [
                'label' => esc_html__('Hover Animation', 'super-floating-flying-menu'),
                'type' => Controls_Manager::HOVER_ANIMATION,
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name' => 'border',
                'selector' => '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close',
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'border_radius', [
                'label' => esc_html__('Border Radius', 'super-floating-flying-menu'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(), [
                'name' => 'button_box_shadow',
                'selector' => '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close',
            ]
        );

        $this->add_responsive_control(
            'button_padding', [
                'label' => esc_html__('Padding', 'super-floating-flying-menu'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .sffm-menu-close-button .sffm-menu-close' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
                    'top' => '15',
                    'right' => '20',
                    'bottom' => '15',
                    'left' => '20',
                    'unit' => 'px',
                    'isLinked' => false,
                ],
                'separator' => 'before',
            ]
        );

        $this->end_controls_section();
    }

    /** Render Layout */
    protected function render() {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute('wrapper', 'class', 'sffm-menu-close-button');

        $this->add_render_attribute('button', 'href', '#');

        $this->add_render_attribute('button', 'class', 'sffm-menu-close');

        if (!empty($settings['hover_animation'])) {
            $this->add_render_attribute('button', 'class', 'elementor-animation-' . $settings['hover_animation']);
        }
        ?>
        <div <?php $this->print_render_attribute_string('wrapper'); ?>>
            <a <?php echo $this->get_render_attribute_string('button'); ?>>
                <?php if (!empty($settings['close_menu_icon']['value'])) { ?>
                    <span class="sffm-menu-close-icon">
                        <?php
                        \Elementor\Icons_Manager::render_icon($settings['close_menu_icon'], ['aria-hidden' => 'true']);
                        ?>
                    </span>
                    <?php
                }

                $this->print_unescaped_setting('close_menu_title');
                ?>
            </a>
        </div>
        <?php
    }

}
