<?php

namespace SFFM\Modules\HoverMenu\Widgets;

// Elementor Classes
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * Tiled Posts Widget
 */
class Hover_Menu extends Widget_Base {

    /** Widget Name */
    public function get_name() {
        return 'sffm-hover-menu';
    }

    /** Widget Title */
    public function get_title() {
        return esc_html__('Animated Hover Menu', 'super-floating-flying-menu');
    }

    /** Icon */
    public function get_icon() {
        return 'eicon-navigation-vertical';
    }

    /** Category */
    public function get_categories() {
        return ['super-floating-flying-menu'];
    }

    /** Controls */
    protected function register_controls() {

        $this->start_controls_section(
            'menuitem', [
                'label' => esc_html__('Content', 'super-floating-flying-menu'),
            ]
        );

        $this->add_control(
            'animation_effect', array(
                'label' => esc_html__('Animation Effect', 'super-floating-flying-menu'),
                'type' => Controls_Manager::SELECT,
                'default' => 'style1',
                'label_block' => true,
                'options' => array(
                    'style1' => esc_html__('Style 1', 'super-floating-flying-menu'),
                    'style2' => esc_html__('Style 2', 'super-floating-flying-menu'),
                    'style3' => esc_html__('Style 3', 'super-floating-flying-menu'),
                    'style4' => esc_html__('Style 4', 'super-floating-flying-menu'),
                    'style5' => esc_html__('Style 5', 'super-floating-flying-menu'),
                    'style6' => esc_html__('Style 6', 'super-floating-flying-menu'),
                    'style7' => esc_html__('Style 7', 'super-floating-flying-menu'),
                    'style8' => esc_html__('Style 8', 'super-floating-flying-menu')
                ),
            )
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'menu_title', [
                'label' => esc_html__('Title', 'super-floating-flying-menu'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'menu_subtitle', [
                'label' => esc_html__('Sub Title', 'super-floating-flying-menu'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'menu_href', [
                'label' => esc_html__('Url', 'super-floating-flying-menu'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
            ]
        );

        $repeater->start_controls_tabs(
            'color_tabs'
        );

        $repeater->start_controls_tab(
            'normal_color_tab', [
                'label' => __('Normal', 'square-plus'),
            ]
        );

        $repeater->add_control(
            'title_color', [
                'label' => esc_html__('Title Color', 'square-plus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.sffm-el-menu-item' => '--sffm-el-menu-title-color: {{VALUE}}',
                ],
            ]
        );

        $repeater->add_control(
            'subtitle_color', [
                'label' => esc_html__('SubTitle Color', 'square-plus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.sffm-el-menu-item' => '--sffm-el-menu-subtitle-color: {{VALUE}}',
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'hover_color_tab', [
                'label' => __('Hover', 'square-plus'),
            ]
        );

        $repeater->add_control(
            'title_color_hover', [
                'label' => esc_html__('Title Color(Hover)', 'square-plus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.sffm-el-menu-item' => '--sffm-el-menu-title-hover-color: {{VALUE}}',
                ],
            ]
        );

        $repeater->add_control(
            'subtitle_color_hover', [
                'label' => esc_html__('SubTitle Color(Hover)', 'square-plus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.sffm-el-menu-item' => '--sffm-el-menu-subtitle-hover-color: {{VALUE}}',
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $this->add_control(
            'menu_block', [
                'label' => esc_html__('Add Menu Items', 'super-floating-flying-menu'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'menu_title' => esc_html__('Menu Heading 1', 'super-floating-flying-menu'),
                        'menu_subtitle' => esc_html__('Menu Subtitle 1', 'super-floating-flying-menu'),
                        'menu_href' => '#'
                    ],
                    [
                        'menu_title' => esc_html__('Menu Heading 2', 'super-floating-flying-menu'),
                        'menu_subtitle' => esc_html__('Menu Subtitle 2', 'super-floating-flying-menu'),
                        'menu_href' => '#'
                    ],
                    [
                        'menu_title' => esc_html__('Menu Heading 3', 'super-floating-flying-menu'),
                        'menu_subtitle' => esc_html__('Menu Subtitle 4', 'super-floating-flying-menu'),
                        'menu_href' => '#'
                    ]
                ],
                'title_field' => '{{{ menu_title }}}',
            ]
        );

        $this->add_responsive_control(
            'menu_item_spacing', [
                'type' => Controls_Manager::SLIDER,
                'label' => esc_html__('Spacing Between Menu', 'plugin-name'),
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'devices' => ['desktop', 'tablet', 'mobile'],
                'default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .sffm-el-menu' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'title_subtile_spacing', [
                'type' => Controls_Manager::SLIDER,
                'label' => esc_html__('Spacing Between Title & SubTitle', 'plugin-name'),
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'devices' => ['desktop', 'tablet', 'mobile'],
                'default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .sffm-el-menu-item' => 'gap: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'animation_effect!' => ['style8'],
                ],
            ]
        );

        $this->add_control(
            'alignment', [
                'label' => __('Alignment', 'super-floating-flying-menu'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'default' => 'center',
                'options' => array(
                    'left' => array(
                        'title' => esc_html__('Left', 'super-floating-flying-menu'),
                        'icon' => !is_rtl() ? 'eicon-text-align-left' : 'eicon-h-align-right',
                    ),
                    'center' => array(
                        'title' => esc_html__('Center', 'super-floating-flying-menu'),
                        'icon' => 'eicon-text-align-center',
                    ),
                    'right' => array(
                        'title' => esc_html__('Right', 'super-floating-flying-menu'),
                        'icon' => !is_rtl() ? 'eicon-text-align-right' : 'eicon-h-align-left',
                    ),
                ),
                'condition' => [
                    'animation_effect!' => ['style3', 'style8'],
                ],
                'toggle' => false
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_before_text_style', array(
                'label' => esc_html__('Text', 'super-floating-flying-menu'),
                'tab' => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => esc_html__('Title Typography', 'super-floating-flying-menu'),
                'name' => 'menu_title_typography',
                'selector' => '{{WRAPPER}} .sffm-el-menu-item-name'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'label' => esc_html__('Subtitle Typography', 'super-floating-flying-menu'),
                'name' => 'menu_subtitle_typography',
                'selector' => '{{WRAPPER}} .sffm-el-menu-item-label'
            ]
        );

        $this->start_controls_tabs(
            'color_tabs'
        );

        $this->start_controls_tab(
            'normal_color_tab', [
                'label' => __('Normal', 'square-plus'),
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => esc_html__('Title Color', 'square-plus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sffm-el-menu-item' => '--sffm-el-menu-title-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'subtitle_color', [
                'label' => esc_html__('SubTitle Color', 'square-plus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sffm-el-menu-item' => '--sffm-el-menu-subtitle-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover_color_tab', [
                'label' => __('Hover', 'square-plus'),
            ]
        );

        $this->add_control(
            'title_color_hover', [
                'label' => esc_html__('Title Color(Hover)', 'square-plus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sffm-el-menu-item' => '--sffm-el-menu-title-hover-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'subtitle_color_hover', [
                'label' => esc_html__('SubTitle Color(Hover)', 'square-plus'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sffm-el-menu-item' => '--sffm-el-menu-subtitle-hover-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();
    }

    /** Render Layout */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $menus = $settings['menu_block'];
        $animation_effect = $settings['animation_effect'];
        $alignment = $settings['alignment'];
        $this->add_render_attribute('wrapper', 'class', [
            'sffm-el-menu',
            'sffm-el-menu--' . esc_attr($animation_effect),
            'sffm-el-menu-align-' . esc_attr($alignment),
        ]);
        ?>
        <nav <?php $this->print_render_attribute_string('wrapper'); ?>>
            <?php
            foreach ($menus as $menu) {
                if ($menu['menu_title'] != '') {
                    ?>
                    <a class="sffm-el-menu-item elementor-repeater-item-<?php echo $menu['_id']; ?>" href="<?php echo esc_url($menu['menu_href']['url']); ?>">
                        <span class="sffm-el-menu-item-name"><?php echo esc_html($menu['menu_title']); ?></span>
                        <?php if ($menu['menu_subtitle'] != '') { ?>
                            <span class="sffm-el-menu-item-label"><?php echo esc_html($menu['menu_subtitle']); ?></span>
                        <?php } ?>
                    </a>
                    <?php
                }
            }
            ?>
        </nav>
        <?php
    }

}
