<?php

namespace SFFM\Modules\MultiLevelMenu\Widgets;

// Elementor Classes
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Repeater;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * Tiled Posts Widget
 */
class Multi_Level_Menu extends Widget_Base {

    /** Widget Name */
    public function get_name() {
        return 'sffm-multi-level-menu';
    }

    /** Widget Title */
    public function get_title() {
        return esc_html__('Multi Level Menu', 'super-floating-flying-menu');
    }

    /** Icon */
    public function get_icon() {
        return 'eicon-navigation-vertical';
    }

    /** Category */
    public function get_categories() {
        return ['super-floating-flying-menu'];
    }

    /** Controls */
    protected function register_controls() {

        $this->start_controls_section(
            'section_static_menu', [
                'label' => __('Layout', 'super-floating-flying-menu'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'dynamic_menu', [
                'label' => esc_html__('Dynamic Menu', 'super-floating-flying-menu'),
                'type' => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'navbar', [
                'label' => esc_html__('Select Menu', 'super-floating-flying-menu'),
                'type' => Controls_Manager::SELECT,
                'options' => sffm_el_get_menu(),
                'default' => 0,
                'condition' => ['dynamic_menu' => 'yes'],
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'menu_title', [
                'label' => __('Menu Title', 'super-floating-flying-menu'),
                'type' => Controls_Manager::TEXT,
                'dynamic' => ['active' => true],
                'label_block' => true,
                'condition' => [
                    'menu_type!' => 'child_end'
                ]
            ]
        );

        $repeater->add_control(
            'menu_type', [
                'label' => __('Select Item Type', 'super-floating-flying-menu'),
                'type' => Controls_Manager::SELECT,
                'dynamic' => ['active' => true],
                'label_block' => true,
                'options' => [
                    'item' => 'Item',
                    'child_start' => 'Child Start',
                    'child_end' => 'Child End',
                ],
                'default' => 'item',
            ]
        );

        $repeater->add_control(
            'menu_link', [
                'label' => __('Link', 'super-floating-flying-menu'),
                'type' => Controls_Manager::URL,
                'dynamic' => ['active' => true],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
                'condition' => [
                    'menu_type!' => 'child_end'
                ]
            ]
        );

        $repeater->add_control(
            'menu_icon', [
                'label' => __('Icon', 'super-floating-flying-menu'),
                'type' => Controls_Manager::ICONS,
                'label_block' => true,
                'condition' => [
                    'menu_type!' => 'child_end'
                ]
            ]
        );

        $this->add_control(
            'menus', [
                'label' => __('Menu Items', 'super-floating-flying-menu'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'condition' => ['dynamic_menu' => ''],
                'separator' => 'before',
                'default' => [
                    [
                        'menu_title' => __('About', 'super-floating-flying-menu'),
                        'menu_link' => '#',
                    ],
                    [
                        'menu_title' => __('Gallery', 'super-floating-flying-menu'),
                        'menu_link' => '#',
                        'menu_type' => 'child_start'
                    ],
                    [
                        'menu_title' => __('Gallery 01', 'super-floating-flying-menu'),
                        'menu_link' => '#',
                    ],
                    [
                        'menu_title' => __('Gallery 02', 'super-floating-flying-menu'),
                        'menu_link' => '#',
                        'menu_type' => 'child_start'
                    ],
                    [
                        'menu_title' => __('Sub Gallery 01', 'super-floating-flying-menu'),
                        'menu_link' => '#',
                    ],
                    [
                        'menu_title' => __('Sub Gallery 02', 'super-floating-flying-menu'),
                        'menu_link' => '#',
                    ],
                    [
                        'menu_title' => __('Sub Gallery 03', 'super-floating-flying-menu'),
                        'menu_link' => '#',
                    ],
                    [
                        'menu_type' => 'child_end'
                    ],
                    [
                        'menu_title' => __('Gallery 03', 'super-floating-flying-menu'),
                        'menu_link' => '#',
                    ],
                    [
                        'menu_type' => 'child_end'
                    ],
                    [
                        'menu_title' => __('Contacts', 'super-floating-flying-menu'),
                        'menu_link' => '#',
                    ],
                ],
                'title_field' => '{{{ elementor.helpers.renderIcon( this, menu_icon, {}, "i", "panel" ) || \'<i class="{{ icon }}" aria-hidden="true"></i>\' }}} <# print( (menu_type == "child_start" ) ? "<b>[ Child Start:</b> " + menu_title : menu_title ) #><# print( (menu_type == "child_end" ) ? "<b>Child End ]</b>" : "" ) #>',
            ]
        );
        $this->end_controls_section();


        //Style
        $this->start_controls_section(
            'sffm_additional', [
                'label' => __('Additional Settings', 'super-floating-flying-menu'),
            ]
        );

        $this->add_control(
            'menu_style', [
                'label' => esc_html__('SubMenu Animation Style', 'super-floating-flying-menu'),
                'type' => Controls_Manager::SELECT,
                'options' => array(
                    '1' => __('Flip', 'super-floating-flying-menu'),
                    '2' => __('Translate X', 'super-floating-flying-menu'),
                    '5' => __('Translate Y', 'super-floating-flying-menu'),
                    '3' => __('Zoom Out', 'super-floating-flying-menu'),
                    '4' => __('Zoom In', 'super-floating-flying-menu')
                ),
                'default' => 1
            ]
        );

        $this->add_control(
            'back_button_text', [
                'label' => __('Back Button Text', 'super-floating-flying-menu'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Back'
            ]
        );

        $this->add_control(
            'sub_menu_indicator', [
                'label' => esc_html__('Sub Menu Indicator', 'super-floating-flying-menu'),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'egi-arrow-carrot-right',
                    'library' => 'sffm-elegant-icon',
                ],
                'label_block' => false,
                'skin' => 'inline',
                'exclude_inline_options' => array('svg'),
            ]
        );
        $this->end_controls_section();

        //Style
        $this->start_controls_section(
            'sffm_item', [
                'label' => __('Menu Items', 'super-floating-flying-menu'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'menu_typography',
                'selector' => '{{WRAPPER}} li.sffm-menu-item > a.sffm-menu-item-link',
            ]
        );

        $this->add_responsive_control(
            'menu_link_spacing', [
                'label' => esc_html__('Space Between Menu Items', 'super-floating-flying-menu'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} li.sffm-menu-item:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name' => 'menu_border',
                'selector' => '{{WRAPPER}} li.sffm-menu-item > a.sffm-menu-item-link',
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'menu_border_radius', [
                'label' => esc_html__('Border Radius', 'super-floating-flying-menu'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors' => [
                    '{{WRAPPER}} li.sffm-menu-item > a.sffm-menu-item-link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'menu_link_padding', [
                'label' => esc_html__('Padding', 'super-floating-flying-menu'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} li.sffm-menu-item > a.sffm-menu-item-link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('menu_link_styles');

        $this->start_controls_tab(
            'menu_link_normal', [
                'label' => esc_html__('Normal', 'super-floating-flying-menu')
            ]
        );

        $this->add_control(
            'menu_link_color', [
                'label' => esc_html__('Color', 'super-floating-flying-menu'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} li.sffm-menu-item > a.sffm-menu-item-link' => 'color: {{VALUE}};',
                    '{{WRAPPER}} li.sffm-menu-item > a.sffm-menu-item-link svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'menu_link_background', [
                'label' => esc_html__('Background', 'super-floating-flying-menu'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} li.sffm-menu-item > a.sffm-menu-item-link' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'menu_link_hover', [
                'label' => esc_html__('Hover', 'super-floating-flying-menu')
            ]
        );

        $this->add_control(
            'menu_link_color_hover', [
                'label' => esc_html__('Color (Hover)', 'super-floating-flying-menu'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} li.sffm-menu-item:hover > a.sffm-menu-item-link' => 'color: {{VALUE}};',
                    '{{WRAPPER}} li.sffm-menu-item:hover > a.sffm-menu-item-link svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'menu_link_background_hover', [
                'label' => esc_html__('Background (Hover)', 'super-floating-flying-menu'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} li.sffm-menu-item:hover > a.sffm-menu-item-link' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'menu_border_color_hover', [
                'label' => esc_html__('Border Color (Hover)', 'super-floating-flying-menu'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} li.sffm-menu-item:hover > a.sffm-menu-item-link' => 'border-color: {{VALUE}};',
                ],
                'condition' => [
                    'menu_border_border!' => '',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();
    }

    /** Render Layout */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();

        $this->add_render_attribute('wrapper_class', [
            'class' => [
                'sffm-menu-container'
            ],
            'data-back-button-text' => $settings['back_button_text'],
            'data-menu-style' => $settings['menu_style'],
            'data-sub-menu-icon' => isset($settings['sub_menu_indicator']['value']) ? $settings['sub_menu_indicator']['value'] : '',
        ]);
        ?>
        <div class="sffm-submenu-animate">
            <div <?php echo $this->get_render_attribute_string('wrapper_class'); ?>>
                <?php
                if ('yes' == $settings['dynamic_menu']):
                    $this->dynamic_menu();
                else:
                    $this->static_menu();
                endif;
                ?>
            </div>
        </div>
        <?php
    }

    protected function static_menu() {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute('wrapper_class_ul', [
            'class' => [
                'sffm-menu'
            ],
        ]);
        ?>
        <ul <?php echo $this->get_render_attribute_string('wrapper_class_ul'); ?>>
            <?php
            foreach ($settings['menus'] as $item):
                $target = (!empty($item['menu_link']['is_external'])) ? ' target="_blank"' : '';
                $nofollow = (!empty($item['menu_link']['nofollow'])) ? ' rel="nofollow"' : '';

                if ($item['menu_type'] == 'child_start') {
                    $item_class = 'sffm-menu-item-link-has-children';
                } else {
                    $item_class = '';
                }
                if ($item['menu_type'] !== 'child_end'):
                    ?>
                    <li class="sffm-menu-item">
                        <a class="sffm-menu-item-link <?php echo $item_class; ?>" href="<?php echo esc_url($item['menu_link']['url']); ?>" <?php echo wp_kses_post($target) . wp_kses_post($nofollow); ?>>
                            <span class="sffm-menu-link-items">
                                <span class="sffm-menu-item-title">
                                    <?php if (!empty($item['menu_icon']['value'])): ?>
                                        <span class="sffm-menu-icon">
                                            <?php Icons_Manager::render_icon($item['menu_icon'], ['aria-hidden' => 'true']); ?>
                                        </span>
                                    <?php endif; ?>
                                    <?php echo $item['menu_title']; ?>
                                </span>
                                <?php
                                if ($item['menu_type'] == 'child_start') {
                                    ?>
                                    <span class="sffm-submenu-toggle"></span>
                                    <?php
                                }
                                ?>
                            </span>
                        </a>
                        <?php
                endif;
                if ($item['menu_type'] == 'child_start'):
                    ?>
                        <ul class="sffm-submenu">
                            <li class="sffm-back sffm-menu-item"><a class="sffm-menu-item-link" href="#"><i class="mdi mdi-chevron-left"></i><span><?php esc_html__('Back', 'super-floating-flying-menu') ?></span></a></li>
                        <?php endif; ?>

                        <?php if ($item['menu_type'] == 'child_end'): ?>
                        </ul>
                    </li>
                    <?php
                        endif;
                        if ($item['menu_type'] == 'item'):
                            ?>
                    </li>
                    <?php
                        endif;
            endforeach;
            ?>
        </ul>
        <?php
    }

    protected function dynamic_menu() {
        $settings = $this->get_settings_for_display();
        $id = 'sffm-menu-' . $this->get_id();
        $nav_menu = !empty($settings['navbar']) ? wp_get_nav_menu_object($settings['navbar']) : false;
        if (!$nav_menu) {
            return;
        }
        $nav_menu_args = array(
            'menu' => $nav_menu,
            'container' => false,
            'menu_id' => 'sffm-menu-' . $id,
            'menu_class' => 'sffm-menu',
            'echo' => true,
            'fallback_cb' => false,
            'walker' => new \SFFM\SFFM_Multi_Level_Walker_Nav_Menu
        );
        wp_nav_menu($nav_menu_args);
    }

}
