<?php

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

class SFFM_Handle_Import_Export {

    public function __construct() {
        // Process a settings export that generates a .json file of the menu settings
        add_action('admin_init', array($this, 'float_imex_process_settings_export'));
        add_action('admin_init', array($this, 'fly_imex_process_settings_export'));

        // Process a settings import from a json file
        add_action('admin_init', array($this, 'float_imex_process_settings_import'));
        add_action('admin_init', array($this, 'fly_imex_process_settings_import'));
        add_action('admin_init', array($this, 'float_imfree_process_settings_import'));
        add_action('admin_init', array($this, 'float_imex_temp_process_settings_import'));
        add_action('admin_init', array($this, 'fly_imex_temp_process_settings_import'));
    }

    public function float_imex_process_settings_export() {

        if (empty($_POST['sffm_floatmenu_imex_action']) || 'export_settings' != $_POST['sffm_floatmenu_imex_action'] || empty($_POST['sffm_floatmenu_menu_id']))
            return;

        if (!wp_verify_nonce($_POST['sffm_floatmenu_imex_export_nonce'], 'sffm_floatmenu_imex_export_nonce'))
            return;

        if (!current_user_can('manage_options'))
            return;

        $menu_id = $_POST['sffm_floatmenu_menu_id'];
        $menu_id_export = 'menu_' . $menu_id;
        $sffm_menu_items = wp_get_nav_menu_items($menu_id);
        $exdat = [];

        foreach ($sffm_menu_items as $item) {
            $exdat['items'][] = array(
                'settings' => $item,
                'meta' => get_post_meta($item->ID, 'sffm_item_settings', true)
            );
        }
        $exdat['menu_type'] = "sffm_floating_menu";
        $exdat['settings'] = get_option('sffm_settings')[$menu_id_export];

        ignore_user_abort(true);

        nocache_headers();
        header('Content-Type: application/json; charset=utf-8');
        header('Content-Disposition: attachment; filename=sffm-floatingmenu-' . date('m-d-Y') . '.json');
        header("Expires: 0");

        echo json_encode($exdat);
        exit;
    }

    public function fly_imex_process_settings_export() {

        if (empty($_POST['sffm_flymenu_imex_action']) || 'export_settings' != $_POST['sffm_flymenu_imex_action'] || empty($_POST['sffm_flymenu_menu_id']))
            return;

        if (!wp_verify_nonce($_POST['sffm_flymenu_imex_export_nonce'], 'sffm_flymenu_imex_export_nonce'))
            return;

        if (!current_user_can('manage_options'))
            return;

        $menu_id = $_POST['sffm_flymenu_menu_id'];
        $menu_id_export = 'menu_' . $menu_id;
        $sffm_menu_items = wp_get_nav_menu_items($menu_id);
        $exdat = [];

        foreach ($sffm_menu_items as $item) {
            $exdat['items'][] = array(
                'settings' => $item,
                'meta' => get_post_meta($item->ID, 'sffm_item_settings', true)
            );
        }
        $exdat['menu_type'] = "sffm_flying_menu";
        $templates = get_option('sffm_menu_template');

        $elemntor_temp_id = isset($templates[$menu_id]) ? $templates[$menu_id] : null;

        $elementor_page = ($elemntor_temp_id && class_exists('Elementor\Plugin') && Elementor\Plugin::instance()->db->is_built_with_elementor($elemntor_temp_id)) ? true : null;
        if ($elementor_page) {
            $dmetas = get_post_meta($elemntor_temp_id);
        }
        $exdat['elementor'] = $elementor_page ? json_decode($dmetas['_elementor_data'][0]) : null;

        $exdat['settings'] = get_option('sffm_settings')[$menu_id_export];

        ignore_user_abort(true);

        nocache_headers();
        header('Content-Type: application/json; charset=utf-8');
        header('Content-Disposition: attachment; filename=sffm-flymenu-' . date('m-d-Y') . '.json');
        header("Expires: 0");

        echo json_encode($exdat);
        exit;
    }

    public function float_imex_process_settings_import() {

        if (empty($_POST['sffm_floatmenu_imex_action']) || 'import_settings' != $_POST['sffm_floatmenu_imex_action'] || empty($_POST['sffm_floatmenu_menu_id']))
            return;

        if (!wp_verify_nonce($_POST['sffm_floatmenu_imex_import_nonce'], 'sffm_floatmenu_imex_import_nonce'))
            return;

        if (!current_user_can('manage_options'))
            return;

        $filename = $_FILES['sffm_floatmenu_import_file']['name'];
        $extension = explode('.', $filename);
        $extension = end($extension);

        if ($extension != 'json') {
            wp_die(esc_html__('Please reload & upload a valid .json file', 'super-floating-flying-menu'));
        }

        $sffm_floatmenu_import_file = $_FILES['sffm_floatmenu_import_file']['tmp_name'];

        if (empty($sffm_floatmenu_import_file)) {
            wp_die(esc_html__('Please reload & upload a file to import', 'super-floating-flying-menu'));
        }

        $sffm_settings = array();
        $menu_id = isset($_POST['sffm_floatmenu_menu_id']) ? absint($_POST['sffm_floatmenu_menu_id']) : null;
        $menu = 'menu_' . $menu_id;

        $nav_menu_items = wp_get_nav_menu_items($menu_id);
        if ($nav_menu_items) {
            foreach ($nav_menu_items as $item) {
                wp_delete_post($item->ID);
            }
        }

        // Retrieve the settings from the file and convert the json object to an array.
        $imdatfile = json_decode(file_get_contents($sffm_floatmenu_import_file), true);
        if (!isset($imdatfile['menu_type']) || (isset($imdatfile['menu_type']) && $imdatfile['menu_type'] != 'sffm_floating_menu')) {
            wp_die(esc_html__('Please reload & upload a valid Floating Menu .json file', 'super-floating-flying-menu'));
        }
        $imsettings[$menu] = $imdatfile['settings'];
        $imsettings[$menu]['menu_id'] = strval($menu_id);
        $sffm_menu_settings = self::import_images($imsettings);
        $item_parent_new_id = [];

        foreach ($imdatfile['items'] as $settings) {
            $settings = self::import_images($settings);
            $menu_item_new = wp_update_nav_menu_item($menu_id, 0, array(
                'menu-item-title' => $settings['settings']['title'],
                'menu-item-status' => 'publish',
                'menu-item-type' => 'custom',
                'menu-item-url' => $settings['settings']['url'],
                'menu-item-classes' => implode(' ', $settings['settings']['classes']),
                'menu-item-description' => $settings['settings']['description'],
                'menu-item-attr-title' => $settings['settings']['attr_title'],
                'menu-item-target' => $settings['settings']['target'],
                'menu-item-xfn' => $settings['settings']['xfn'],
                'menu-item-parent-id' => $settings['settings']['menu_item_parent'] ? $item_parent_new_id[$settings['settings']['menu_item_parent']] : 0,
            ));
            $item_parent_new_id[$settings['settings']['ID']] = $menu_item_new;
            update_post_meta($menu_item_new, 'sffm_item_settings', $settings['meta']);
        }
        $sffm_settings_all = get_option('sffm_settings');
        unset($sffm_settings_all[$menu_id]);
        update_option('sffm_settings', array_merge($sffm_settings_all, $sffm_menu_settings));
    }

    public function fly_imex_process_settings_import() {

        if (empty($_POST['sffm_flymenu_imex_action']) || 'import_settings' != $_POST['sffm_flymenu_imex_action'] || empty($_POST['sffm_flymenu_menu_id']))
            return;

        if (!wp_verify_nonce($_POST['sffm_flymenu_imex_import_nonce'], 'sffm_flymenu_imex_import_nonce'))
            return;

        if (!current_user_can('manage_options'))
            return;

        $filename = $_FILES['sffm_flymenu_import_file']['name'];
        $extension = explode('.', $filename);
        $extension = end($extension);

        if ($extension != 'json') {
            wp_die(esc_html__('Please reload & upload a valid .json file', 'super-floating-flying-menu'));
        }

        $sffm_flymenu_import_file = $_FILES['sffm_flymenu_import_file']['tmp_name'];

        if (empty($sffm_flymenu_import_file)) {
            wp_die(esc_html__('Please reload & upload a file to import', 'super-floating-flying-menu'));
        }

        $sffm_settings = array();
        $menu_id = isset($_POST['sffm_flymenu_menu_id']) ? absint($_POST['sffm_flymenu_menu_id']) : null;
        $menu = 'menu_' . $menu_id;

        $nav_menu_items = wp_get_nav_menu_items($menu_id);
        if ($nav_menu_items) {
            foreach ($nav_menu_items as $item) {
                wp_delete_post($item->ID);
            }
        }

        // Retrieve the settings from the file and convert the json object to an array.
        $imdatfile = json_decode(file_get_contents($sffm_flymenu_import_file), true);
        if (!isset($imdatfile['menu_type']) || (isset($imdatfile['menu_type']) && $imdatfile['menu_type'] != 'sffm_flying_menu')) {
            wp_die(esc_html__('Please reload & upload valid Fly Menu .json file', 'super-floating-flying-menu'));
        }
        $imsettings[$menu] = $imdatfile['settings'];
        $imsettings[$menu]['menu_id'] = strval($menu_id);
        $sffm_menu_settings = self::import_images($imsettings);
        $elemntor_temp = isset($imdatfile['elementor']) ? $imdatfile['elementor'] : '';
        $item_parent_new_id = [];

        foreach ($imdatfile['items'] as $settings) {
            $settings = self::import_images($settings);
            $menu_item_new = wp_update_nav_menu_item($menu_id, 0, array(
                'menu-item-title' => $settings['settings']['title'],
                'menu-item-status' => 'publish',
                'menu-item-type' => 'custom',
                'menu-item-url' => $settings['settings']['url'],
                'menu-item-classes' => implode(' ', $settings['settings']['classes']),
                'menu-item-description' => $settings['settings']['description'],
                'menu-item-attr-title' => $settings['settings']['attr_title'],
                'menu-item-target' => $settings['settings']['target'],
                'menu-item-xfn' => $settings['settings']['xfn'],
                'menu-item-parent-id' => $settings['settings']['menu_item_parent'] ? $item_parent_new_id[$settings['settings']['menu_item_parent']] : 0,
            ));
            $item_parent_new_id[$settings['settings']['ID']] = $menu_item_new;
            update_post_meta($menu_item_new, 'sffm_item_settings', $settings['meta']);
        }
        $sffm_settings_all = get_option('sffm_settings');
        unset($sffm_settings_all[$menu_id]);
        update_option('sffm_settings', array_merge($sffm_settings_all, $sffm_menu_settings));

        if ($elemntor_temp) {
            $templates = get_option('sffm_menu_template');
            $elemntor_temp_id = isset($templates[$menu_id]) ? $templates[$menu_id] : null;

            if (!is_null(get_post($elemntor_temp_id))) {
                wp_delete_post($elemntor_temp_id, true);
            }
            $new_post = array(
                'post_type' => 'sffm-menu',
                'post_title' => 'sffm-floatflymenu-' . $menu_id,
                'post_status' => 'publish',
                'meta_input' => array(
                    '_elementor_data' => json_encode($elemntor_temp),
                    '_elementor_edit_mode' => 'builder',
                    '_elementor_template_type' => 'section',
                    '_elementor_version' => defined('ELEMENTOR_VERSION') ? ELEMENTOR_VERSION : '3.12',
                ),
            );
            $post_id = wp_insert_post($new_post);
            $templates[$menu_id] = $post_id;
            update_option('sffm_menu_template', $templates);
        }
    }

    public function float_imfree_process_settings_import() {

        if (empty($_POST['sffm_floatmenu_imfree_action']) || 'import_settings' != $_POST['sffm_floatmenu_imfree_action'] || empty($_POST['sffm_floatmenu_menu_id']))
            return;

        if (!wp_verify_nonce($_POST['sffm_floatmenu_imfree_import_nonce'], 'sffm_floatmenu_imfree_import_nonce'))
            return;

        if (!current_user_can('manage_options'))
            return;

        $filename = $_FILES['sffm_floatmenu_import_file']['name'];
        $extension = explode('.', $filename);
        $extension = end($extension);

        if ($extension != 'json') {
            wp_die(esc_html__('Please reload & upload a valid .json file', 'super-floating-flying-menu'));
        }

        $sffm_floatmenu_import_file = $_FILES['sffm_floatmenu_import_file']['tmp_name'];

        if (empty($sffm_floatmenu_import_file)) {
            wp_die(esc_html__('Please reload & upload a file to import', 'super-floating-flying-menu'));
        }

        $sffm_settings = array();
        $menu_id = isset($_POST['sffm_floatmenu_menu_id']) ? absint($_POST['sffm_floatmenu_menu_id']) : null;
        $menu = 'menu_' . $menu_id;

        $nav_menu_items = wp_get_nav_menu_items($menu_id);
        if ($nav_menu_items) {
            foreach ($nav_menu_items as $item) {
                wp_delete_post($item->ID);
            }
        }

        // Retrieve the settings from the file and convert the json object to an array.
        $sfm_settings = json_decode(file_get_contents($sffm_floatmenu_import_file), true);

        $sffm_settings[$menu]['menu_enabled'] = true;
        $sffm_settings[$menu]['menu_id'] = $menu_id;
        $sffm_settings[$menu]['menu_type'] = 'floating_menu';
        $sffm_settings[$menu]['floatmenu']['enable_floatmenu'] = true;
        $sffm_settings[$menu]['floatmenu']['template'] = 'floatmenu-template-1';
        $sffm_settings[$menu]['floatmenu']['display_condition'] = 'show_all';
        $sffm_settings[$menu]['floatmenu']['temp_1_position'] = $sfm_settings['position'];
        $sffm_settings[$menu]['floatmenu']['temp_1_orientation'] = $sfm_settings['orientation'];
        $sffm_settings[$menu]['floatmenu']['floatmenu_height'] = $sfm_settings['button_height'];
        $sffm_settings[$menu]['floatmenu']['floatmenu_width'] = $sfm_settings['button_width'];
        $sffm_settings[$menu]['icon_size'] = $sfm_settings['icon_size'];
        $sffm_settings[$menu]['z_index'] = $sfm_settings['zindex'];

        $buttons_settings = $sfm_settings['buttons'];
        $menuitem_settings = array();

        foreach ($buttons_settings as $index => $settings) {
            $menu_item_new = wp_update_nav_menu_item($menu_id, 0, array(
                'menu-item-title' => $settings['tool_tip_text'],
                'menu-item-status' => 'publish',
                'menu-item-type' => 'custom',
                'menu-item-url' => $settings['url']
            ));

            $menuitem_settings = SFFM_Admin_Templates::default_settings();
            $menuitem_settings['floatingmenu']['tooltip_enable'] = 'on';
            $menuitem_settings['floatingmenu']['tooltip_text'] = $settings['tool_tip_text'];
            $menuitem_settings['floatingmenu']['icon_type'] = 'available_icon';
            $menuitem_settings['floatingmenu']['item_customize_enable'] = true;
            $menuitem_settings['floatingmenu']['available_icon'] = $settings['icon'];
            $menuitem_settings['floatingmenu']['bg_color'] = $settings['button_bg_color'];
            $menuitem_settings['floatingmenu']['icon_color'] = $settings['button_icon_color'];
            $menuitem_settings['floatingmenu']['hover_bg_color'] = $settings['button_bg_color_hover'];
            $menuitem_settings['floatingmenu']['hover_icon_color'] = $settings['button_icon_color_hover'];
            $menuitem_settings['floatingmenu']['tooltip_bg_color'] = $settings['tooltip_bg_color'];
            $menuitem_settings['floatingmenu']['tooltip_text_color'] = $settings['tooltip_text_color'];

            update_post_meta($menu_item_new, 'sffm_item_settings', $menuitem_settings);
        }

        $sffm_settings_all = get_option('sffm_settings');
        unset($sffm_settings_all[$menu]);
        update_option('sffm_settings', array_merge($sffm_settings_all, $sffm_settings));
    }

    public function float_imex_temp_process_settings_import() {

        if (empty($_POST['sffm_floatmenu_imex_action']) || 'import_temp_settings' != $_POST['sffm_floatmenu_imex_action'] || empty($_POST['sffm_floatmenu_menu_id']))
            return;

        if (!wp_verify_nonce($_POST['sffm_floatmenu_imex_import_temp_nonce'], 'sffm_floatmenu_imex_import_temp_nonce'))
            return;

        if (!current_user_can('manage_options'))
            return;

        $sffm_import_template = $_POST['sffm_import_template'];
        if (empty($sffm_import_template)) {
            wp_die(__('Please select a template to import'));
        }

        $import_file = SFFM_PATH . 'admin/inc/import-files/' . str_replace('_', '-', $sffm_import_template) . '.json';
        $options = array('associative' => true);

        $imdatfile = wp_json_file_decode($import_file, $options);

        $sffm_settings = array();
        $menu_id = isset($_POST['sffm_floatmenu_menu_id']) ? absint($_POST['sffm_floatmenu_menu_id']) : null;
        $menu = 'menu_' . $menu_id;

        $nav_menu_items = wp_get_nav_menu_items($menu_id);
        if ($nav_menu_items) {
            foreach ($nav_menu_items as $item) {
                wp_delete_post($item->ID);
            }
        }

        if (!isset($imdatfile['menu_type']) || (isset($imdatfile['menu_type']) && $imdatfile['menu_type'] != 'sffm_floating_menu')) {
            wp_die(esc_html__('Please reload & upload a valid Floating Menu .json file', 'super-floating-flying-menu'));
        }
        $imsettings[$menu] = $imdatfile['settings'];
        $imsettings[$menu]['menu_id'] = strval($menu_id);
        $sffm_menu_settings = self::import_images($imsettings);
        $item_parent_new_id = [];

        foreach ($imdatfile['items'] as $settings) {
            $settings = self::import_images($settings);
            $menu_item_new = wp_update_nav_menu_item($menu_id, 0, array(
                'menu-item-title' => $settings['settings']['title'],
                'menu-item-status' => 'publish',
                'menu-item-type' => 'custom',
                'menu-item-url' => $settings['settings']['url'],
                'menu-item-classes' => implode(' ', $settings['settings']['classes']),
                'menu-item-description' => $settings['settings']['description'],
                'menu-item-attr-title' => $settings['settings']['attr_title'],
                'menu-item-target' => $settings['settings']['target'],
                'menu-item-xfn' => $settings['settings']['xfn'],
                'menu-item-parent-id' => $settings['settings']['menu_item_parent'] ? $item_parent_new_id[$settings['settings']['menu_item_parent']] : 0,
            ));
            $item_parent_new_id[$settings['settings']['ID']] = $menu_item_new;
            update_post_meta($menu_item_new, 'sffm_item_settings', $settings['meta']);
        }
        $sffm_settings_all = get_option('sffm_settings');
        unset($sffm_settings_all[$menu_id]);
        update_option('sffm_settings', array_merge($sffm_settings_all, $sffm_menu_settings));
    }

    public function fly_imex_temp_process_settings_import() {

        if (empty($_POST['sffm_flymenu_imex_action']) || 'import_temp_settings' != $_POST['sffm_flymenu_imex_action'] || empty($_POST['sffm_flymenu_menu_id']))
            return;

        if (!wp_verify_nonce($_POST['sffm_flymenu_imex_import_temp_nonce'], 'sffm_flymenu_imex_import_temp_nonce'))
            return;

        if (!current_user_can('manage_options'))
            return;

        $sffm_import_template = $_POST['sffm_import_template'];
        if (empty($sffm_import_template)) {
            wp_die(__('Please select a template to import'));
        }

        $import_file = SFFM_PATH . 'admin/inc/import-files/' . str_replace('_', '-', $sffm_import_template) . '.json';
        $options = array('associative' => true);

        $imdatfile = wp_json_file_decode($import_file, $options);

        $sffm_settings = array();
        $menu_id = isset($_POST['sffm_flymenu_menu_id']) ? absint($_POST['sffm_flymenu_menu_id']) : null;
        $menu = 'menu_' . $menu_id;

        $nav_menu_items = wp_get_nav_menu_items($menu_id);
        if ($nav_menu_items) {
            foreach ($nav_menu_items as $item) {
                wp_delete_post($item->ID);
            }
        }

        if (!isset($imdatfile['menu_type']) || (isset($imdatfile['menu_type']) && $imdatfile['menu_type'] != 'sffm_flying_menu')) {
            wp_die(esc_html__('Please reload & upload valid Fly Menu .json file', 'super-floating-flying-menu'));
        }
        $imsettings[$menu] = $imdatfile['settings'];
        $imsettings[$menu]['menu_id'] = strval($menu_id);
        $sffm_menu_settings = self::import_images($imsettings);
        $elemntor_temp = isset($imdatfile['elementor']) ? $imdatfile['elementor'] : '';
        $item_parent_new_id = [];

        foreach ($imdatfile['items'] as $settings) {
            $settings = self::import_images($settings);
            $menu_item_new = wp_update_nav_menu_item($menu_id, 0, array(
                'menu-item-title' => $settings['settings']['title'],
                'menu-item-status' => 'publish',
                'menu-item-type' => 'custom',
                'menu-item-url' => $settings['settings']['url'],
                'menu-item-classes' => implode(' ', $settings['settings']['classes']),
                'menu-item-description' => $settings['settings']['description'],
                'menu-item-attr-title' => $settings['settings']['attr_title'],
                'menu-item-target' => $settings['settings']['target'],
                'menu-item-xfn' => $settings['settings']['xfn'],
                'menu-item-parent-id' => $settings['settings']['menu_item_parent'] ? $item_parent_new_id[$settings['settings']['menu_item_parent']] : 0,
            ));
            $item_parent_new_id[$settings['settings']['ID']] = $menu_item_new;
            update_post_meta($menu_item_new, 'sffm_item_settings', $settings['meta']);
        }
        $sffm_settings_all = get_option('sffm_settings');
        unset($sffm_settings_all[$menu_id]);
        update_option('sffm_settings', array_merge($sffm_settings_all, $sffm_menu_settings));

        if ($elemntor_temp) {
            $templates = get_option('sffm_menu_template');
            $elemntor_temp_id = isset($templates[$menu_id]) ? $templates[$menu_id] : null;

            if (!is_null(get_post($elemntor_temp_id))) {
                wp_delete_post($elemntor_temp_id, true);
            }
            $new_post = array(
                'post_type' => 'sffm-menu',
                'post_title' => 'sffm-floatflymenu-' . $menu_id,
                'post_status' => 'publish',
                'meta_input' => array(
                    '_elementor_data' => json_encode($elemntor_temp),
                    '_elementor_edit_mode' => 'builder',
                    '_elementor_template_type' => 'section',
                    '_elementor_version' => defined('ELEMENTOR_VERSION') ? ELEMENTOR_VERSION : '3.12',
                ),
            );
            $post_id = wp_insert_post($new_post);
            $templates[$menu_id] = $post_id;
            update_option('sffm_menu_template', $templates);
        }
    }

    /**
     * Imports images for settings saved as mods.
     *
     * @param  array $mods An array of customizer mods.
     * @return array The mods array with any new import data.
     */
    private static function import_images($mods) {
        foreach ($mods as $key => $value) {

            //For repeater fields
            if (is_array($value)) {
                foreach ($value as $data_key => $data_value) {
                    if (is_array($data_value)) {
                        $value[$data_key] = self::import_images($data_value);
                    } else {
                        if (self::is_image_url($data_value)) {
                            $sub_data = self::media_handle_sideload($data_value);
                            if (!is_wp_error($sub_data))
                                $value[$data_key] = $sub_data->url;
                        } else {
                            $value[$data_key] = $data_value;
                        }
                    }
                }

                $mods[$key] = $value;
            } elseif (self::is_image_url($value)) {
                $data = self::media_handle_sideload($value);
                if (!is_wp_error($data))
                    $mods[$key] = $data->url;
            }
        }

        return $mods;
    }

    /**
     * Checks to see whether a url is an image url or not.
     *
     * @param  string $url The url to check.
     * @return bool Whether the url is an image url or not.
     */
    private static function is_image_url($url) {
        if (is_string($url) && preg_match('/\.(jpg|jpeg|png|gif)/i', $url)) {
            return true;
        }

        return false;
    }

    /**
     * Taken from the core media_sideload_image function and
     * modified to return an array of data instead of html.
     *
     * @param  string $file The image file path.
     * @return array An array of image data.
     */
    private static function media_handle_sideload($file) {
        $data = new stdClass();

        if (!function_exists('media_handle_sideload')) {
            require_once(ABSPATH . 'wp-admin/includes/media.php');
            require_once(ABSPATH . 'wp-admin/includes/file.php');
            require_once(ABSPATH . 'wp-admin/includes/image.php');
        }

        if (!empty($file)) {
            // Set variables for storage, fix file filename for query strings.
            preg_match('/[^\?]+\.(jpe?g|jpe|gif|png)\b/i', $file, $matches);
            $file_array = array();
            $file_array['name'] = basename($matches[0]);

            // Download file to temp location.
            $file_array['tmp_name'] = download_url($file);

            // If error storing temporarily, return the error.
            if (is_wp_error($file_array['tmp_name'])) {
                return $file_array['tmp_name'];
            }

            // Do the validation and storage stuff.
            $id = media_handle_sideload($file_array, 0);

            // If error storing permanently, unlink.
            if (is_wp_error($id)) {
                @unlink($file_array['tmp_name']);
                return $id;
            }

            // Build the object to return.
            $meta = wp_get_attachment_metadata($id);
            $data->attachment_id = $id;
            $data->url = wp_get_attachment_url($id);
            $data->thumbnail_url = wp_get_attachment_thumb_url($id);
            $data->height = $meta['height'];
            $data->width = $meta['width'];
        }

        return $data;
    }

}

new SFFM_Handle_Import_Export();
