<?php

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

/**
 * Class Menu_Post_Type
 * @package SFFM_Menu
 */
class SFFM_Register_Post_Type {

    /**
     * A reference to an instance of this class.
     *
     * @since 1.0.0
     * @var   object
     */
    private static $instance = null;

    /**
     * Returns the instance.
     *
     * @since  1.0.0
     * @return object
     */
    public static function get_instance() {

        // If the single instance hasn't been set, set it now.
        if (null == self::$instance) {
            self::$instance = new self;
        }
        return self::$instance;
    }

    /**
     * Constructor for the class
     */
    public function __construct() {

        add_action('init', array($this, 'register_post_type'));
        add_action('after_setup_theme', array($this, 'edit_redirect'));
        add_filter('single_template', array($this, 'load_template'));
    }

    /**
     * Register post type
     *
     * @return void
     */
    public function register_post_type() {

        $labels = array(
            'name' => esc_html__('SFFM Menu Templates', 'super-floating-flying-menu'),
            'singular_name' => esc_html__('SFFM Menu Template', 'super-floating-flying-menu'),
            'add_new' => esc_html__('Add New SFFM Menu Template', 'super-floating-flying-menu'),
            'add_new_item' => esc_html__('Add New SFFM Menu Template', 'super-floating-flying-menu'),
            'edit_item' => esc_html__('Edit SFFM Menu Template', 'super-floating-flying-menu'),
            'menu_name' => esc_html__('SFFM Menu Templates', 'super-floating-flying-menu'),
        );

        $args = array(
            'labels' => $labels,
            'hierarchical' => false,
            'description' => 'description',
            'taxonomies' => array(),
            'public' => true,
            'show_ui' => false,
            'show_in_menu' => true,
            'show_in_admin_bar' => true,
            'menu_position' => null,
            'menu_icon' => null,
            'show_in_nav_menus' => false,
            'publicly_queryable' => true,
            'exclude_from_search' => true,
            'has_archive' => false,
            'query_var' => true,
            'can_export' => true,
            'rewrite' => true,
            'capability_type' => 'post',
            'supports' => array('title', 'editor', 'elementor'),
        );

        register_post_type('sffm-menu', $args);
    }

    /**
     * Edit redirect
     *
     * @return void
     */
    public function edit_redirect() {

        if (!current_user_can('manage_options')) {
            return;
        }

        if (empty($_REQUEST['sffm-open-editor'])) {
            return;
        }

        if (empty($_REQUEST['item'])) {
            return;
        }

        $menu_id = intval($_REQUEST['item']);
        $templates = get_option('sffm_menu_template');
        $sffm_menu_id = isset($templates[$menu_id]) ? $templates[$menu_id] : null;

        if (!$sffm_menu_id || 'publish' != get_post_status($sffm_menu_id)) {
            $sffm_menu_id = wp_insert_post(array(
                'post_title' => 'sffm-floatflymenu-' . $menu_id,
                'post_status' => 'publish',
                'post_type' => 'sffm-menu',
            ));
            $templates[$menu_id] = $sffm_menu_id;
            update_option('sffm_menu_template', $templates);
        }

        $edit_link = add_query_arg(
            array(
                'post' => $sffm_menu_id,
                'action' => 'elementor',
                'context' => 'sffm-menu',
            ), admin_url('post.php')
        );

        wp_redirect($edit_link);
        die();
    }

    public function load_template($template) {
        global $post;

        if ('sffm-menu' === $post->post_type && locate_template(array('single-sffm-menu.php')) !== $template) {
            return SFFM_PATH . 'admin/inc/templates/blank.php';
        }

        return $template;
    }

}

new SFFM_Register_Post_Type();
