<?php

/**
 * Class SFFM_Admin_Templates
 *
 * Main class for supporting mega men in the theme.
 */
class SFFM_Admin_Templates {

    /**
     * Modal screen of mega menu settings
     *
     * @var array
     */
    public $modals = array();
    public $flyFloatModals = array();

    /**
     * Class constructor.
     */
    public function __construct() {
        $this->modals = apply_filters('sffm_addons_floatfly_menu_item_modal_panels', array(
            'float-item-general',
            'float-item-design',
            'fly-item-general',
            'menu',
            'title',
            'toolbar'
        ));

        $this->flyFloatModals = apply_filters('sffm_addons_flyfloat_menu_modal_panels', array(
            'floatdesign',
            'floatdisplay',
            'floatgeneral',
            'floatlayout',
            'floatimex',
            'floatimfree',
            'flycontentpanel',
            'flycontent',
            'flydesign',
            'flydisplay',
            'flylayout',
            'flytrigger',
            'flyimex'
        ));

        add_action('wp_nav_menu_item_custom_fields', array($this, 'floatfly_menu_item'), 10, 5);
        add_action('admin_footer-nav-menus.php', array($this, 'modal'));
        add_action('admin_footer-nav-menus.php', array($this, 'templates'));
        add_action('admin_footer-nav-menus.php', array($this, 'saving_alert'));

        /* Activate Plugin */
        add_action('wp_ajax_sffm_activate_plugin', array($this, 'activate_plugin'));

        add_action('admin_enqueue_scripts', array($this, 'scripts'));

        // Get posts by query
        add_action('wp_ajax_sffm_get_posts_by_query', array($this, 'get_posts_by_query'));
        add_action('wp_ajax_sffm_set_selected_options', array($this, 'set_selected_options'));
    }

    public function floatfly_menu_item($item_id) {
        $floatFlyItemData = get_post_meta($item_id, 'sffm_item_settings', true);
        $floatFlyItemData = sffm_recurse_parse_args($floatFlyItemData, SFFM_Admin_Templates::default_settings());

        // Adds floatfly menu item data holder
        ?>
        <span data-mega="<?php echo esc_attr(json_encode($floatFlyItemData)); ?>" class="hidden mega-data"></span>
        <span class="sffm-menu-item-settings">
            <span class="sffm-menu-item-settings-trigger">
                <span class="icofont-gear"></span>
                <?php echo esc_html('Super Menu Setting', 'super-floating-flying-menu'); ?>
            </span>
        </span>
        <?php
    }

    /**
     * Load scripts on Menus page only
     *
     * @param string $hook
     */
    public function scripts($hook) {
        if ('nav-menus.php' !== $hook) {
            return;
        }

        if (is_rtl()) {
            wp_enqueue_style('sffm-floatfly-menu-admin', SFFM_URL . '/admin/css/sffm-menu.rtl.css', array('media-views', 'wp-color-picker'));
        } else {
            wp_enqueue_style('sffm-floatfly-menu-admin', SFFM_URL . '/admin/css/sffm-menu.css', array('media-views', 'wp-color-picker'));
        }

        wp_enqueue_script('sffm-floatfly-menu-admin', SFFM_URL . '/admin/js/sffm-menu.js', array('jquery', 'jquery-ui-resizable', 'wp-util', 'wp-color-picker', 'plugin-install', 'updates'), null, true);
        wp_localize_script('sffm-floatfly-menu-admin', 'sffmMenuModal', $this->modals);
        wp_localize_script('sffm-floatfly-menu-admin', 'sffmFlyFloatMenuModal', $this->flyFloatModals);
        wp_localize_script('sffm-floatfly-menu-admin', 'sffmMenuData', array(
            'admin_url' => admin_url(),
            'admin_menu_url' => admin_url('nav-menus.php'),
            'admin_nonce' => wp_create_nonce('sffm-backend-ajax-nonce'),
            'admin_img_dir' => SFFM_URL . '/admin/inc/img/',
            'sffm_complete_font_variants' => sffm_get_complete_font_families(),
            'sffm_default_font_families' => sffm_get_default_font_families(),
            'sffm_google_font_families' => sffm_get_google_font_families(),
            'sffm_standard_font_families' => sffm_get_standard_font_families(),
            'sffm_text_transform_choices' => sffm_get_text_transform_choices(),
            'sffm_text_decoration_choices' => sffm_get_text_decoration_choices(),
            'animation_options' => $this->animation_options(),
            'sffm_font_icons' => sffm_icons_array(),
            'installing_text' => esc_html__('Installing Elementor', 'super-floating-flying-menu'),
            'activating_text' => esc_html__('Activating Elementor', 'super-floating-flying-menu'),
            'error' => esc_html__('Error! Reload the page and try again.', 'super-floating-flying-menu'),
            'menu_enabled_text' => esc_html__('Settings Saved.. Super Floating and Flying Menu Enabled.', 'super-floating-flying-menu'),
            'menu_disabled_text' => esc_html__('Settings Saved.. Super Floating and Flying Menu Disabled.', 'super-floating-flying-menu'),
            'floating_menu_enabled_text' => esc_html__('Settings Saved.. Floating Menu Enabled.', 'super-floating-flying-menu'),
            'flying_menu_enabled_text' => esc_html__('Settings Saved.. Flying Menu Enabled.', 'super-floating-flying-menu'),
        ));
        wp_enqueue_editor();
    }

    /**
     * Prints HTML of modal on footer
     */
    public function modal() {
        ?>
        <div id="sffm-mega-menu" tabindex="0" class="sffm-mega-menu">
            <div class="sffm-modal media-modal wp-core-ui">
                <button type="button" class="button-link media-modal-close sffm-modal-close">
                    <span class="media-modal-icon"><span class="screen-reader-text"><?php esc_html_e('Close', 'super-floating-flying-menu') ?></span></span>
                </button>
                <div class="media-modal-content">
                    <div class="sffm-frame-title"></div>

                    <div class="sffm-frame-wrap">
                        <div class="sffm-frame-menu">
                            <div class="sffm-menu"></div>
                        </div>

                        <div class="sffm-frame-content">
                            <div class="sffm-content"></div>
                        </div>
                    </div>

                    <div class="sffm-frame-toolbar">
                        <div class="sffm-toolbar wp-clearfix"></div>
                    </div>
                </div>
            </div>
            <div class="media-modal-backdrop sffm-modal-backdrop"></div>
        </div>
        <?php
    }

    /**
     * Prints underscore template on footer
     */
    public function templates() {
        foreach ($this->modals as $template) {
            $file = SFFM_PATH . '/admin/inc/views/menu-' . $template . '.php';
            if (!file_exists($file)) {
                continue;
            }
            ?>
            <script type="text/html" id="tmpl-sffm-<?php echo esc_attr($template) ?>">
                <?php include($file); ?>
            </script>
            <?php
        }

        foreach ($this->flyFloatModals as $template) {
            $file = SFFM_PATH . '/admin/inc/views/menu-' . $template . '.php';
            if (!file_exists($file)) {
                continue;
            }
            ?>
            <script type="text/html" id="tmpl-sffm-<?php echo esc_attr($template) ?>">
                <?php include($file); ?>
            </script>
            <?php
        }
    }

    /**
     * Define default flyfloat menu item settings
     */
    public static function default_settings() {
        return apply_filters('sffm_floatfly_menu_item_default', array(
            'floatingmenu' => array(
                'tooltip_enable' => 'on',
                'tooltip_text' => '',
                'target_blank' => 'off',
                'icon_type' => 'available_icon',
                'action' => 'default',
                'scroll_sectionid' => '',
                'img_icon' => '',
                'available_icon' => 'icofont-gear',
                'bg_color' => '',
                'hover_bg_color' => '',
                'icon_color' => '',
                'hover_icon_color' => '',
                'tooltip_bg_color' => '',
                'tooltip_hover_bg_color' => '',
                'tooltip_text_color' => '',
                'tooltip_hover_text_color' => ''
            ),
            'flymenu' => array(
                'icon_type' => 'none',
                'available_icon' => '',
                'img_icon' => '',
                'short_description' => '',
                'notification_label' => '',
                'additional_content' => '',
                'push_menu_additional_content' => '',
            ),
        ));
    }

    /**
     * Define default flyfloat menu settings
     */
    public static function default_flyfloat_settings() {
        return apply_filters('sffm_floatfly_menu_default', array(
            'menu_enabled' => false,
            'menu_id' => null,
            'menu_type' => 'floating_menu',
            'floatmenu' => array(
                'template' => 'floatmenu-template-1',
                'temp_1_tab_shape' => 'square',
                'temp_56_tab_shape' => 'square',
                'temp_1_position' => 'middle-left',
                'temp_1_orientation' => 'vertical',
                'temp_1_offset_top' => '',
                'temp_1_offset_left' => '',
                'temp_1_offset_bottom' => '',
                'temp_1_offset_right' => '',
                'temp_7_position' => 'middle-left',
                'temp_7_offset_top' => '',
                'temp_7_offset_left' => '',
                'temp_7_offset_bottom' => '',
                'temp_7_offset_right' => '',
                'temp_8_position' => 'middle-left',
                'temp_8_offset_top' => '',
                'temp_8_offset_left' => '',
                'temp_8_offset_bottom' => '',
                'temp_8_offset_right' => '',
                'temp_9_position' => 'middle-left',
                'temp_9_orientation' => 'vertical',
                'temp_9_offset_top' => '',
                'temp_9_offset_left' => '',
                'temp_9_offset_bottom' => '',
                'temp_9_offset_right' => '',
                'temp_10_position' => 'bottom-left',
                'temp_10_offset_top' => '',
                'temp_10_offset_left' => '',
                'temp_10_offset_bottom' => '',
                'temp_10_offset_right' => '',
                'temp_11_position' => 'bottom-left',
                'temp_11_radius' => 150,
                'temp_11_offset_top' => '',
                'temp_11_offset_left' => '',
                'temp_11_offset_bottom' => '',
                'temp_11_offset_right' => '',
                'temp_12_position' => 'middle-left',
                'temp_12_radius' => 150,
                'temp_12_offset_top' => '',
                'temp_12_offset_left' => '',
                'temp_12_offset_bottom' => '',
                'temp_12_offset_right' => '',
                'temp_13_position' => 'middle-left',
                'temp_13_radius' => 150,
                'temp_13_offset_top' => '',
                'temp_13_offset_left' => '',
                'temp_13_offset_bottom' => '',
                'temp_13_offset_right' => '',
                'temp_14_position' => 'middle-right',
                'temp_14_offset_left' => '',
                'temp_14_offset_right' => '',
                'temp_14_animation' => 'animation-1',
                'temp_14_scroll_top_offset' => '',
                'temp_style' => 'style-1',
                'animation' => 'step-fade',
                'zindex' => '',
                'button_size' => 50,
                'icon_size' => '',
                'tab_spacing' => '',
                'nav_item_spacing' => '',
                'nav_item_size' => '',
                'icon_type' => 'default_icon',
                'hamburger_icon_type' => 'style1',
                'tab_default_icon' => 'sffm-menu-icon-12',
                'tab_default_close_icon' => 'sffm-close-icon-8',
                'tab_custom_icon' => '',
                'tab_custom_close_icon' => '',
                'trigger_btn_hvr_animation' => 'none',
                'trigger_btn_idle_animation' => 'none',
                'open_item_on' => 'click',
                'open_items_on_load' => 'off',
                'hide_screen' => [],
                'display_condition' => 'show_all',
                'front_pages' => 'off',
                'blog_pages' => 'off',
                'archive_pages' => 'off',
                'error_pages' => 'off',
                'search_pages' => 'off',
                'cpt_pages' => [],
                'specific_pages' => [],
                'specific_archive' => [],
                'polylang_display_condition' => 'show_all',
                'polylang_show_hide_languages' => [],
                'button_bg_color' => '',
                'button_hover_bg_color' => '',
                'button_icon_color' => '',
                'button_hover_icon_color' => '',
                'nav_item_bg_color' => '',
                'nav_item_border_color' => '',
                'nav_item_hover_border_color' => '',
                'nav_item_hover_bg_color' => '',
                'nav_item_active_bg_color' => '',
                'nav_item_active_border_color' => '',
                'button_shadow' => array(
                    'x' => '',
                    'y' => '',
                    'blur' => '',
                    'spread' => '',
                    'color' => ''
                ),
                'tooltip_bg_color' => '',
                'tooltip_text_color' => '',
                'tooltip_hover_bg_color' => '',
                'tooltip_hover_text_color' => '',
                'tooltip_font_family' => 'Default',
                'tooltip_font_style' => 'Default',
                'tooltip_text_transform' => 'inherit',
                'tooltip_text_decoration' => 'inherit',
                'tooltip_font_size' => '',
                'tooltip_line_height' => '',
                'tooltip_letter_spacing' => '',
                'trigger_btn_bg_color' => '',
                'trigger_btn_icon_color' => '',
                'trigger_btn_hover_bg_color' => '',
                'trigger_btn_hover_icon_color' => '',
                'circle_bg_color' => '',
                'buttons_bg_color' => '',
                'trigger_btn_size' => '',
                'trigger_btn_icon_size' => '',
                'floatmenu_trigger_btn_size' => '',
                'floatmenu_trigger_btn_icon_size' => '',
                'hamburger_width' => '',
                'hamburger_spacing' => '',
                'hamburger_thickness' => ''
            ),
            'flymenu' => array(
                'custom_display_content_from' => 'custom-content',
                'content_alignment' => 'middle',
                'header_text_option' => 'no_text',
                'custom_header_text' => '',
                'custom_tagline_text' => '',
                'header_img_option' => 'no_image',
                'custom_header_image' => '',
                'header_custom_content' => '',
                'header_content_alignment' => 'center',
                'header_image_width' => '80',
                'header_image_width_unit' => '%',
                'header_element_spacing' => '40',
                'searchform_area' => 'none',
                'searchform_placeholder' => '',
                'search_form_width' => '100',
                'social_icons_area' => 'none',
                'social_icon' => array(),
                'social_icons_shape' => 'square',
                'social_icons_button_size' => '',
                'social_icons_icon_size' => '',
                'footer_custom_content' => '',
                'footer_content_alignment' => 'center',
                'footer_element_spacing' => '40',
                'menu_animation' => 'slide-bottom',
                'body_content_alignment' => 'left',
                'flymenu_layout' => 'side-menu',
                'overlay_color' => 'rgba(0,0,0,.8)',
                'side_menu_submenu_animation' => 'menu-drop',
                'skew_side_menu_submenu_animation' => 'menu-drop',
                'skew_side_menu_inclination' => 'forward',
                'skew_side_menu_angle' => '15',
                'fullscreen_menu_column' => 'column-1',
                'fullscreen_menu_submenu_animation' => 'animation-1',
                'fullscreen_content_width' => '600',
                'fullscreen_content_width_unit' => 'px',
                'panel_wave_color_1' => '',
                'panel_wave_color_2' => '',
                'panel_wave_color_3' => '',
                'panel_wave_color_4' => '',
                'icon_menu_submenu_animation' => 'menu-drop',
                'menu_hover_animation' => 'linear-slide',
                'overlay_type' => 'color-background',
                'parent_menu_clickable' => 'off',
                'auto_close_panel' => 'on',
                'social_link_new_tab' => 'on',
                'freeze_scrollbar' => 'on',
                'submenu_toggle_open_icon' => 'mdi mdi-plus',
                'submenu_toggle_close_icon' => 'mdi mdi-minus',
                'hide_screen' => [],
                'display_condition' => 'show_all',
                'specific_pages' => [],
                'specific_archive' => [],
                'front_pages' => null,
                'blog_pages' => null,
                'archive_pages' => null,
                'error_pages' => null,
                'search_pages' => null,
                'cpt_pages' => [],
                'polylang_display_condition' => 'show_all',
                'polylang_show_hide_languages' => [],
                'toggle_button' => array(
                    'icon_type' => 'default_icon',
                    'shape' => 'round',
                    'hamburger_icon_type' => 'style1',
                    'open_icon' => 'sffm-menu-icon-1',
                    'close_icon' => 'sffm-close-icon-1',
                    'custom_open_icon' => '',
                    'custom_close_icon' => '',
                    'hvr_animation' => 'none',
                    'idle_animation' => 'none',
                    'position' => 'middle-left',
                    'offset_top' => '',
                    'offset_bottom' => '',
                    'offset_left' => '',
                    'offset_right' => '',
                    'size' => '',
                    'icon_size' => '',
                    'image_size' => 60,
                    'hamburger_width' => '',
                    'hamburger_spacing' => '',
                    'hamburger_thickness' => '',
                    'iconmenu_icon_type' => 'default_icon',
                    'iconmenu_hamburger_icon_type' => 'style1',
                    'iconmenu_open_icon' => 'sffm-menu-icon-1',
                    'iconmenu_close_icon' => 'sffm-close-icon-1',
                    'iconmenu_custom_open_icon' => '',
                    'iconmenu_custom_close_icon' => '',
                    'iconmenu_image_size' => 100,
                    'iconmenu_icon_size' => '',
                    'iconmenu_hamburger_width' => '',
                    'iconmenu_hamburger_spacing' => '',
                    'iconmenu_hamburger_thickness' => '',
                    'insert_on_menu' => 'off',
                    'menu' => '',
                    'menu_icon' => 'sffm-menu-icon-1',
                    'menu_icon_position' => 'after-menu',
                    'open_panel_on' => 'click',
                    'button_bg_color' => '',
                    'button_hover_bg_color' => '',
                    'button_icon_color' => '',
                    'button_hover_icon_color' => '',
                    'button_shadow_x' => '',
                    'button_shadow_y' => '',
                    'button_shadow_blur' => '',
                    'button_shadow_color' => '',
                ),
                'panel_animation' => 'default',
                'fullscreen_panel_animation' => 'fade-in',
                'panel_position' => 'right',
                'panel_show_animation' => 'bounceInDown',
                'panel_hide_animation' => 'bounceOutDown',
                'panel_width' => '400',
                'panel_width_unit' => 'px',
                'panel_show_scrollbar' => 'off',
                'scrollbar_width' => '',
                'scrollbar_drag_rail_color' => '',
                'scrollbar_drag_bar_color' => '',
                'panel_background_type' => 'color',
                'panel_background_color' => '#000000',
                'panel_background_image' => '',
                'panel_background_repeat' => 'repeat',
                'panel_background_size' => 'cover',
                'panel_background_position' => 'center center',
                'panel_background_attachment' => 'fixed',
                'panel_overlay_color' => '',
                'panel_video_url' => '',
                'panel_video_background_image' => '',
                'panel_video_overlay_color' => '',
                'zindex' => '999999',
                'panel_spacing' => array(
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ),
                'header_spacing' => array(
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ),
                'menu_spacing' => array(
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ),
                'footer_spacing' => array(
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ),
                'menu_item_spacing' => array(
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ),
                'search_spacing' => array(
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ),
                'header_title_font_family' => 'Default',
                'header_title_font_style' => 'Default',
                'header_title_text_transform' => 'inherit',
                'header_title_text_decoration' => 'inherit',
                'header_title_font_size' => '',
                'header_title_line_height' => '',
                'header_title_letter_spacing' => '',
                'header_tagline_font_family' => 'Default',
                'header_tagline_font_style' => 'Default',
                'header_tagline_text_transform' => 'inherit',
                'header_tagline_text_decoration' => 'inherit',
                'header_tagline_font_size' => '',
                'header_tagline_line_height' => '',
                'header_tagline_letter_spacing' => '',
                'header_text_font_family' => 'Default',
                'header_text_font_style' => 'Default',
                'header_text_text_transform' => 'inherit',
                'header_text_text_decoration' => 'inherit',
                'header_text_font_size' => '',
                'header_text_line_height' => '',
                'header_text_letter_spacing' => '',
                'menu_label_font_family' => 'Default',
                'menu_label_font_style' => 'Default',
                'menu_label_text_transform' => 'inherit',
                'menu_label_text_decoration' => 'inherit',
                'menu_label_font_size' => '',
                'menu_label_line_height' => '',
                'menu_label_letter_spacing' => '',
                'menu_desc_font_family' => 'Default',
                'menu_desc_font_style' => 'Default',
                'menu_desc_text_transform' => 'inherit',
                'menu_desc_text_decoration' => 'inherit',
                'menu_desc_font_size' => '',
                'menu_desc_line_height' => '',
                'menu_desc_letter_spacing' => '',
                'menu_content_font_family' => 'Default',
                'menu_content_font_style' => 'Default',
                'menu_content_text_transform' => 'inherit',
                'menu_content_text_decoration' => 'inherit',
                'menu_content_font_size' => '',
                'menu_content_line_height' => '',
                'menu_content_letter_spacing' => '',
                'footer_text_font_family' => 'Default',
                'footer_text_font_style' => 'Default',
                'footer_text_text_transform' => 'inherit',
                'footer_text_text_decoration' => 'inherit',
                'footer_text_font_size' => '',
                'footer_text_line_height' => '',
                'footer_text_letter_spacing' => '',
                'header_title_color' => '',
                'header_tagline_color' => '',
                'header_text_color' => '',
                'menu_label_color' => '',
                'menu_bg_color' => '',
                'menu_border_color' => '',
                'menu_label_color_hover' => '',
                'menu_bg_color_hover' => '',
                'menu_border_color_hover' => '',
                'menu_short_desc_color' => '',
                'menu_add_content_color' => '',
                'menu_notification_color' => '',
                'menu_notification_bg_color' => '',
                'footer_text_color' => '',
                'search_bg_color' => '',
                'search_border_color' => '',
                'search_text_color' => '',
                'search_button_color' => '',
                'search_button_icon_color' => '',
                'search_form_border_radius' => '',
                'socialicon_icon_color' => '',
                'socialicon_bg_color' => '',
                'socialicon_border_color' => '',
                'socialicon_tooltip_color' => '',
                'socialicon_tooltip_bg_color' => '',
                'socialicon_icon_color_hover' => '',
                'socialicon_bg_color_hover' => '',
                'socialicon_border_color_hover' => '',
                'close_button_position' => 'right',
                'close_button_icon_color' => '',
                'close_button_icon_color_hover' => '',
                'close_button_bg_color' => '',
                'close_button_bg_color_hover' => '',
                'close_button_size' => '',
                'close_button_border_radius' => '',
                'close_button_offset' => array(
                    'top' => '',
                    'right' => '',
                    'left' => ''
                ),
            ),
        ));
    }

    public function animation_options() {
        $animations = array(
            'show_animation' => array(
                'Bouncing Entrances' => array('bounceIn', 'bounceInDown', 'bounceInLeft', 'bounceInRight', 'bounceInUp'),
                'Fading Entrances' => array('fadeIn', 'fadeInDown', 'fadeInDownBig', 'fadeInLeft', 'fadeInLeftBig', 'fadeInRight', 'fadeInRightBig', 'fadeInUp', 'fadeInUpBig'),
                'Slide Entrance' => array('slideInUp', 'slideInDown', 'slideInLeft', 'slideInRight'),
                'Zoom Entrances' => array('zoomIn', 'zoomInDown', 'zoomInLeft', 'zoomInRight', 'zoomInUp'),
                'Flip Entrances' => array('flipInX', 'flipInY'),
                'Lightspeed Entrances' => array('lightSpeedInLeft', 'lightSpeedInRight'),
                'Back Entrances' => array('backInDown', 'backInLeft', 'backInRight', 'backInUp'),
                'Rotate Entrances' => array('rotateIn', 'rotateInDownLeft', 'rotateInDownRight', 'rotateInUpLeft', 'rotateInUpRight', 'rollIn')
            ),
            'hide_animation' => array(
                'Bouncing Exits' => array('bounceOut', 'bounceOutDown', 'bounceOutLeft', 'bounceOutRight', 'bounceOutUp'),
                'Fading Exits' => array('fadeOut', 'fadeOutDown', 'fadeOutDownBig', 'fadeOutLeft', 'fadeOutLeftBig', 'fadeOutRight', 'fadeOutRightBig', 'fadeOutUp', 'fadeOutUpBig'),
                'Slide Exits' => array('slideOutUp', 'slideOutDown', 'slideOutLeft', 'slideOutRight'),
                'Zoom Exits' => array('zoomOut', 'zoomOutDown', 'zoomOutLeft', 'zoomOutRight', 'zoomOutUp'),
                'Flip Exits' => array('flipOutX', 'flipOutY'),
                'Lightspeed Exits' => array('lightSpeedOutLeft', 'lightSpeedOutRight'),
                'Back Exits' => array('backOutDown', 'backOutLeft', 'backOutRight', 'backOutUp'),
                'Rotate Exits' => array('rotateOut', 'rotateOutDownLeft', 'rotateOutDownRight', 'rotateOutUpLeft', 'rotateOutUpRight', 'rollOut')
            ),
            'hover_animation' => array(
                'Grow' => 'hvr-grow',
                'Shrink' => 'hvr-shrink',
                'Pulse' => 'hvr-pulse',
                'Pulse Grow' => 'hvr-pulse-grow',
                'Pulse Shrink' => 'hvr-pulse-shrink',
                'Push' => 'hvr-push',
                'Pop' => 'hvr-pop',
                'Bounce In' => 'hvr-bounce-in',
                'Bounce Out' => 'hvr-bounce-out',
                'Tilt' => 'hvr-rotate',
                'Grow Tilt' => 'hvr-grow-rotate',
                'Float' => 'hvr-float',
                'Sink' => 'hvr-sink',
                'Bob' => 'hvr-bob',
                'Hang' => 'hvr-hang',
                'Skew' => 'hvr-skew',
                'Skew Forward' => 'hvr-skew-forward',
                'Skew Backward' => 'hvr-skew-backward',
                'Wobble Horizontal' => 'hvr-wobble-horizontal',
                'Wobble Vertical' => 'hvr-wobble-vertical',
                'Wobble To Bottom Right' => 'hvr-wobble-to-bottom-right',
                'Wobble To Top Right' => 'hvr-wobble-to-top-right',
                'Wobble Top' => 'hvr-wobble-top',
                'Wobble Bottom' => 'hvr-wobble-bottom',
                'Wobble Skew' => 'hvr-wobble-skew',
                'Buzz' => 'hvr-buzz',
                'Buzz Out' => 'hvr-buzz-out',
                'Forward' => 'hvr-forward',
                'Backward' => 'hvr-backward'
            ),
        );
        return $animations;
    }

    public function saving_alert() {
        ?>
        <div class="sffm-alert">
            <span class="sffm-alert-message"></span>
            <i class="icofont-close-line"></i>
        </div>
        <?php
    }

    /** Ajax Plugin Activation */
    public function activate_plugin() {
        $slug = isset($_POST['slug']) ? $_POST['slug'] : '';
        $file = isset($_POST['file']) ? $_POST['file'] : '';
        $success = false;

        if (!empty($slug) && !empty($file)) {
            $result = activate_plugin($slug . '/' . $file . '.php');
            if (!is_wp_error($result)) {
                $success = true;
            }
        }
        echo wp_json_encode(array('success' => $success));
        die();
    }

    public function get_posts_by_query() {
        $search_string = isset($_POST['q']) ? sanitize_text_field(wp_unslash($_POST['q'])) : ''; // phpcs:ignore
        $post_type = isset($_POST['post_type']) ? $_POST['post_type'] : 'post'; // phpcs:ignore
        $results = array();

        add_filter('posts_where', array($this, 'title_filter'), 10, 2);
        $query = new WP_Query(array(
            'title_filter' => $search_string,
            'post_status' => 'publish',
            'post_type' => $post_type,
            'posts_per_page' => -1,
        ));
        remove_filter('posts_where', array($this, 'title_filter'), 10, 2);
        wp_reset_postdata();

        if (!isset($query->posts)) {
            return;
        }

        foreach ($query->posts as $post) {
            $results[] = array(
                'id' => $post->ID,
                'text' => $post->post_title,
            );
        }
        wp_send_json(['results' => $results]);
    }

    public function title_filter($where, $wp_query) {
        global $wpdb;
        if ($search_term = $wp_query->get('title_filter')) {
            $where .= ' AND ' . $wpdb->posts . '.post_title LIKE \'%' . esc_sql($wpdb->esc_like($search_term)) . '%\'';
        }
        return $where;
    }

    public function set_selected_options() {
        $post_type = isset($_POST['post_type']) ? $_POST['post_type'] : 'post';
        $selected_ids = isset($_POST['selected_ids']) ? $_POST['selected_ids'] : '';
        $results = array();

        $query = new WP_Query(array(
            's' => $search_string,
            'post_type' => $post_type,
            'post__in' => explode(',', $selected_ids),
            'posts_per_page' => -1,
        ));
        wp_reset_postdata();

        if (!isset($query->posts)) {
            return;
        }

        foreach ($query->posts as $post) {
            $results[] = array(
                'id' => $post->ID,
                'text' => $post->post_title,
            );
        }
        wp_send_json(['results' => $results]);
    }

}

new SFFM_Admin_Templates();
