var sffm = sffm || {};

(function ($, _) {
    'use strict';

    var wp = window.wp;

    sffm = {
        init: function () {
            this.$body = $(document.body);
            this.$modal = $('#sffm-mega-menu');
            this.itemData = {};
            this.floatFlyData = {};
            this.templates = {};
            this.flyFloatTemplates = {};
            this.colorPicker = '';
            this.initializedFloatDisplay = false;
            this.initializedFlyDisplay = false;

            this.frame = wp.media({
                library: {
                    type: 'image'
                }
            });
            this.initTemplates();
            this.initFlyFloatTemplates();
            this.initActions();
            this.addActiveClass();
            var selectOptionHtml = '',
                iconHtml = '',
                activeClass = ' active';
            if (sffmMenuData.sffm_font_icons) {
                _.each(sffmMenuData.sffm_font_icons, function (label, choice) {
                    selectOptionHtml += '<option value="' + choice + '">' + label.name + '</option>';
                    iconHtml += '<ul class="sffm-icon-list ' + choice + activeClass + '">';
                    _.each(label.icons, function (icon) {
                        iconHtml += '<li><i class="' + icon + '"></i></li>';
                    });
                    iconHtml += '</ul>';
                    activeClass = '';
                });
            }
            this.selectOptionHtml = selectOptionHtml;
            this.iconHtml = iconHtml;
        },

        initTemplates: function () {
            _.each(sffmMenuModal, function (name) {
                sffm.templates[name] = wp.template('sffm-' + name);
            });
        },

        initFlyFloatTemplates: function () {
            _.each(sffmFlyFloatMenuModal, function (name) {
                sffm.flyFloatTemplates[name] = wp.template('sffm-' + name);
            });
        },

        initActions: function () {
            sffm.$body
                .on('click', '.sffm-menu-item-settings-trigger', this.openModal)
                .on('click', '#sffm-menu-settings__trigger', this.openFlyFloatModal)
                .on('click', '.sffm-modal-backdrop, .sffm-modal-close, .sffm-button-cancel', this.closeModal)
                .on('click', '.sffm-open-floatfly-editor', this.openEditor)
                .on('click', '.sffm-menu-popup-close', this.closeEditor)
                .on('click', '#sffm_select_menu', this.enableFloatFly)
                .on('click', '#sffm-floatingmenu-checkbox, #sffm-flymenu-checkbox', this.updateFloatFly);
            sffm.$modal
                .on('click', '.sffm-menu a.sffm-fly-float-item', this.switchPanel)
                .on('click', '.sffm-menu a.sffm-fly-float-menu-settings', this.switchFloatFlyPanel)
                .on('click', '.sffm-button-save', this.saveChanges)
                .on('click', '.sffm-button-floatfly-save', this.saveFloatFlyChanges)
                .on('change', '.sffm-typography-font-family', this.updateTypographyWeight)
                .on('click', '.sffm-activate-elementor-plugin', this.activateElementor)
                .on('click', '.sffm-install-elementor-plugin', this.installElementor)
                .on('click', '#sffm-add-social-icon', this.addSocialIcon)
                .on('change', '.sffm-dropzone', this.sffmReadFile)
                .on('dragover', '.sffm-dropzone-wrapper', this.sffmDragOverDropzone)
                .on('dragleave', '.sffm-dropzone-wrapper', this.sffmDragLeaveDropzone)
                .on('click', '.sffm-remove-preview', this.sffmRemovePreview)
                .on('click', '.sffm-hide-show-cpt-posts', this.sffmShowCPTPost)
                .on('click', '#floatmenu_archive_pages, #flymenu_archive_pages', this.sffmShowHideArchiveList)
                .on('change', '.sffm_import_template_form select[name="sffm_import_template"]', this.importTemplateSetup)
                .on('click', '.sffm-submenu-tab', this.toggleSubMenuTabs);
        },

        openModal: function (event) {
            event.preventDefault();
            sffm.getItemData(this);
            sffm.$modal.show();
            sffm.$body.addClass('modal-open');
            sffm.render();
            sffm.initToggleFields();
            return false;
        },

        openFlyFloatModal: function (event) {
            event.preventDefault();
            sffm.getFlyFloatData(this);
            sffm.$modal.show();
            sffm.$body.addClass('modal-open');
            sffm.renderFlyFloat();
            sffm.initToggleFields();
            return false;
        },

        closeModal: function () {
            sffm.$modal.hide().find('.sffm-content').html('');
            sffm.$body.removeClass('modal-open');
            sffm.initializedFloatDisplay = false;
            sffm.initializedFlyDisplay = false;
            return false;
        },

        addActiveClass: function () {
            if ($('#sffm_select_menu').is(':checked')) {
                $('#menu-management-liquid').addClass('sffm-active');
            }
        },

        enableFloatFly: function () {
            let selected_menu_id = $(this).data('sffm-selected-menu-id'),
                menu_name = $(this).data('sffm-menu-name'),
                menu_slug = $(this).data('sffm-menu-slug'),
                $sel_menu = $(this).closest('#super-floating-flying-menu-settings'),
                $floatMenu = $sel_menu.find('#sffm-floatingmenu-checkbox'),
                $flyMenu = $sel_menu.find('#sffm-flymenu-checkbox'),
                $floatFlyMenuTypeSettings = $sel_menu.find('.sffm-menu-type-settings'),
                $menuType = $floatMenu.is(':checked') ? 'floating_menu' : $flyMenu.is(':checked') ? 'fly_menu' : '';

            if (this.checked) {
                if (!$menuType) {
                    $floatMenu.prop("checked", true);
                }
                $floatFlyMenuTypeSettings.show();
                $('#menu-management-liquid').addClass('sffm-active');
                $.ajax({
                    url: ajaxurl,
                    type: 'post',
                    data: {
                        action: "sffm_menu_select",
                        menu_id: selected_menu_id,
                        menu_name: menu_name,
                        menu_slug: menu_slug,
                        wp_nonce: sffmMenuData.admin_nonce
                    }
                });

                $('.sffm-alert').addClass('sffm-alert-success');
                $('.sffm-alert span').html(sffmMenuData.menu_enabled_text);
                $('.sffm-alert').addClass('sffm-alert-active');
                sffm.hideAlert(3500);
            } else {
                $floatFlyMenuTypeSettings.hide();
                $('#menu-management-liquid').removeClass('sffm-active');
                $.ajax({
                    url: ajaxurl,
                    type: 'post',
                    data: {
                        action: "sffm_menu_deselect",
                        menu_id: selected_menu_id,
                        menu_name: menu_name,
                        menu_slug: menu_slug,
                        wp_nonce: sffmMenuData.admin_nonce
                    }
                });

                $('.sffm-alert').addClass('sffm-alert-success');
                $('.sffm-alert span').html(sffmMenuData.menu_disabled_text);
                $('.sffm-alert').addClass('sffm-alert-active');
                sffm.hideAlert(3500);
            }

            $('.sffm-alert .icofont-close-line').on('click', function () {
                sffm.hideAlert(100);
            });
        },

        updateFloatFly: function () {
            let selected_menu_id = $(this).data('sffm-selected-menu-id'),
                selected_menu_type = $(this).val();
            var setting_text = (selected_menu_type == 'floating_menu') ? sffmMenuData.floating_menu_enabled_text : sffmMenuData.flying_menu_enabled_text;
            if (this.checked) {
                $.ajax({
                    url: ajaxurl,
                    type: 'post',
                    data: {
                        action: "sffm_menu_floatfly",
                        menu_id: selected_menu_id,
                        menu_type: selected_menu_type,
                        wp_nonce: sffmMenuData.admin_nonce
                    }
                });

                $('.sffm-alert').addClass('sffm-alert-success');
                $('.sffm-alert span').html(setting_text);
                $('.sffm-alert').addClass('sffm-alert-active');
                sffm.hideAlert(3500);
            }
        },

        openEditor: function () {
            var el = $(this);
            var menu_id = el.data('menu-id');
            $('.sffm-button-floatfly-save').trigger('click');
            setTimeout(function () {
                $('#sffm-mega-menu').hide();
                $('body').addClass('sffm-menu-popup-active');
                $('<div class="sffm-menu-popup" data-menu-id="' + menu_id + '">' +
                    '<div class="sffm-menu-popup-content">' +
                    '<div class="sffm-menu-popup-close">' +
                    '<i class="elementor-icon eicon-close"></i>' +
                    '</div>' +
                    '<iframe src="' + sffmMenuData.admin_url + '?sffm-open-editor=1&item=' + menu_id + '"></iframe>' +
                    '</div>' +
                    '</div>').appendTo('body');
            }, 1000);
        },

        closeEditor: function () {
            var menu_id = $(this).closest('.sffm-menu-popup').data('menu-id');
            $('#sffm-mega-menu').show();
            $('.sffm-menu-popup').remove();
            $('body').removeClass('sffm-menu-popup-active');
            $('.sffmplus-open-megamenu-editor[data-menu-id="' + menu_id + '"]:not(.sffmplus-editor-initialized)').text('Edit Template');
        },

        switchPanel: function (e) {
            e.preventDefault();
            var $el = $(this),
                panel = $el.data('panel');

            $el.addClass('active').siblings('.active').removeClass('active');
            sffm.openSettings(panel);
        },

        switchFloatFlyPanel: function (e) {
            e.preventDefault();
            var $el = $(this),
                panel = $el.data('panel');

            $el.addClass('active').siblings('.active').removeClass('active');
            sffm.openFloatFlySettings(panel);
        },

        render: function () {
            if (sffm.itemData.depth != 0 && sffm.itemData.menuType == 'floating_menu') {
                // Render menu
                sffm.$modal.find('.sffm-frame-menu').hide();
                sffm.$modal.find('.sffm-frame-menu .sffm-menu').html('');
                sffm.$modal.find('.sffm-frame-content .sffm-content').html('<i class="mdi mdi-block-helper"></a>');
                // Render toolbar
                sffm.$modal.find('.sffm-frame-toolbar .sffm-toolbar').html('');
                sffm.$modal.find('.sffm-frame-title').html(sffm.templates.title({title: 'Floating Menu doesn\'t support submenus.'}));
            } else {
                // Render menu
                sffm.$modal.find('.sffm-frame-menu').show();
                sffm.$modal.find('.sffm-frame-menu .sffm-menu').html(sffm.templates.menu(sffm.itemData));

                var $activeMenu = sffm.$modal.find('.sffm-menu a.active');

                // Render content
                this.openSettings($activeMenu.data('panel'));

                // Render toolbar
                sffm.$modal.find('.sffm-frame-toolbar .sffm-toolbar').html(sffm.templates.toolbar(sffm.itemData));
            }
        },

        renderFlyFloat: function () {
            // Render menu
            sffm.$modal.find('.sffm-frame-menu .sffm-menu').html(sffm.templates.menu(sffm.floatFlyData));

            var $activeMenu = sffm.$modal.find('.sffm-menu a.active');

            // Render content
            this.openFloatFlySettings($activeMenu.data('panel'));
            // Render toolbar
            sffm.$modal.find('.sffm-frame-toolbar .sffm-toolbar').html(sffm.templates.toolbar(sffm.floatFlyData));

        },

        openSettings: function (panel) {
            var $content = sffm.$modal.find('.sffm-frame-content .sffm-content'),
                $panel = $content.children('#sffm-panel-' + panel);

            if ($panel.length) {
                $panel.addClass('active').siblings().removeClass('active');
            } else {
                $content.append(sffm.templates[panel](sffm.itemData));
                $content.children('#sffm-panel-' + panel).addClass('active').siblings().removeClass('active');

                if ('float-item-design' === panel) {
                    sffm.initDesignFields();
                }
                sffm.initToggleFields();
            }

            // Render title
            var title = sffm.$modal.find('.sffm-frame-menu .sffm-menu a[data-panel=' + panel + ']').data('title');
            sffm.$modal.find('.sffm-frame-title').html(sffm.templates.title({title: title}));
        },

        openFloatFlySettings: function (panel) {
            var $content = sffm.$modal.find('.sffm-frame-content .sffm-content'),
                $panel = $content.children('#sffm-panel-' + panel);

            if ($panel.length) {
                $panel.addClass('active').siblings().removeClass('active');
            } else {
                $content.append(sffm.flyFloatTemplates[panel](sffm.floatFlyData));
                $content.children('#sffm-panel-' + panel).addClass('active').siblings().removeClass('active');
                sffm.initDesignFields();
                sffm.initTypographyFields();
                sffm.initSortableFields();
                sffm.initToggleFields();
            }

            if (!sffm.initializedFloatDisplay && 'floatdisplay' === panel) {
                sffm.initializedFloatDisplay = true;
                sffm.$modal.find('.floatmenu-specific-pages-ids').each(sffm.select2Search);
            }

            if (!sffm.initializedFlyDisplay && 'flydisplay' === panel) {
                sffm.initializedFlyDisplay = true;
                sffm.$modal.find('.flymenu-specific-pages-ids').each(sffm.select2Search);
            }

            // Render title
            var title = sffm.$modal.find('.sffm-frame-menu .sffm-menu a[data-panel=' + panel + ']').data('title');
            sffm.$modal.find('.sffm-frame-title').html(sffm.templates.title({title: title, depth: sffm.itemData.depth}));
        },

        initTypographyFields: function () {
            sffm.$modal.find('.sffm-typography-input-field > select').chosen({width: "100%"});
            // Range JS
            sffm.$modal.find('.sffm-range-input-selector').each(function () {
                var newSlider = $(this);
                var sliderValue = newSlider.val();
                var sliderMinValue = parseFloat(newSlider.attr('min'));
                var sliderMaxValue = parseFloat(newSlider.attr('max'));
                var sliderStepValue = parseFloat(newSlider.attr('step'));
                newSlider.prev('.sffm-range-slider').slider({
                    value: sliderValue,
                    min: sliderMinValue,
                    max: sliderMaxValue,
                    step: sliderStepValue,
                    range: 'min',
                    slide: function (e, ui) {
                        $(this).next().val(ui.value);
                    }
                });
            });

            // Update slider if the input field loses focus as it's most likely changed
            sffm.$modal.find('.sffm-range-input-selector').blur(function () {
                var resetValue = isNaN($(this).val()) ? '' : $(this).val();

                if (resetValue) {
                    var sliderMinValue = parseFloat($(this).attr('min'));
                    var sliderMaxValue = parseFloat($(this).attr('max'));
                    // Make sure our manual input value doesn't exceed the minimum & maxmium values
                    if (resetValue < sliderMinValue) {
                        resetValue = sliderMinValue;
                    }
                    if (resetValue > sliderMaxValue) {
                        resetValue = sliderMaxValue;
                    }
                }
                $(this).val(resetValue);
                $(this).prev('.sffm-range-slider').slider('value', resetValue);
            });
        },

        initDesignFields: function () {
            sffm.$modal.find('.background-color-picker, .color-picker').wpColorPicker();
        },

        initSocialIconFields: function () {
            sffm.colorPicker = sffm.$body.find('#sffm-each-socialicon-custom-fields-block').eq(0).clone();
            sffm.$body.find('#sffm-each-socialicon-custom-fields-block').remove();
        },

        initToggleFields: function () {
            sffm.$modal.find('[data-condition="toggle"]').each(function () {
                $(this).conditionToggle();
                $(this).change();
            });
        },

        initSortableFields: function () {
            sffm.$modal.find('#sffm-social-icon-list').sortable({
                cursor: "move",
                axis: "y",
                update: function (event, ui) {
                    $('.sffm-social-icon-list').each(function (i) {
                        i = i + 1;
                        $(this).find('[name]').each(function () {
                            var name = $(this).attr('name');
                            $(this).attr('name', name.substr(0, name.indexOf("[") + 1) + i + name.substr(name.indexOf("]")));
                        });
                    });
                }
            });
        },

        getItemData: function (menuItem) {
            var $menuItem = $(menuItem).closest('li.menu-item'),
                $menuData = $menuItem.find('.mega-data'),
                children = $menuItem.childMenuItems(),
                megaData = $menuData.data('mega'),
                $menu = $(document).find('#super-floating-flying-menu-settings'),
                $floatFlyData = $menu.find('.floatflysettings-data'),
                floatFlyData = $floatFlyData.data('floatflysettings'),
                $floatMenu = $menu.find('#sffm-floatingmenu-checkbox'),
                $flyMenu = $menu.find('#sffm-flymenu-checkbox'),
                $menuType = $floatMenu.is(':checked') ? 'floating_menu' : $flyMenu.is(':checked') ? 'fly_menu' : '';

            megaData.content = $menuData.html();

            sffm.itemData = {
                depth: $menuItem.menuItemDepth(),
                megaData: megaData,
                menuType: $menuType,
                data: $menuItem.getItemData(),
                children: [],
                element: $menuItem.get(0),
                floatFlyData: floatFlyData
            };

            if (!_.isEmpty(children)) {
                _.each(children, function (item) {
                    var $item = $(item),
                        $itemData = $item.find('.mega-data'),
                        depth = $item.menuItemDepth(),
                        megaData = $itemData.data('mega');

                    megaData.content = $itemData.html();

                    sffm.itemData.children.push({
                        depth: depth,
                        subDepth: depth - sffm.itemData.depth - 1,
                        data: $item.getItemData(),
                        megaData: megaData,
                        element: item
                    });
                });
            }
        },

        getFlyFloatData: function (menu) {
            var $menu = $(menu).closest('#super-floating-flying-menu-settings'),
                $menuData = $menu.find('#sffm_select_menu'),
                $floatMenu = $menu.find('#sffm-floatingmenu-checkbox'),
                $flyMenu = $menu.find('#sffm-flymenu-checkbox'),
                $menuType = $floatMenu.is(':checked') ? 'floating_menu' : $flyMenu.is(':checked') ? 'fly_menu' : '',
                $floatFlyData = $menu.find('.floatflysettings-data'),
                floatFlyData = $floatFlyData.data('floatflysettings');

            floatFlyData.content = $floatFlyData.html();
            sffm.floatFlyData = {
                flyfloatenabled: $menuData.is(':checked'),
                menuType: $menuType,
                menuId: $menuData.data('sffm-selected-menu-id'),
                floatFlyData: floatFlyData
            };

        },

        setItemData: function (item, data) {
            var $dataHolder = $(item).find('.mega-data');

            if (_.has(data, 'content')) {
                $dataHolder.html(data.content);
                delete data.content;
            }

            $dataHolder.data('mega', data);
        },

        setFloatFlyData: function (data) {
            var $floatFlyDataHolder = $('#super-floating-flying-menu-settings .floatflysettings-data');

            if (_.has(data, 'content')) {
                $floatFlyDataHolder.html(data.content);
                delete data.content;
            }

            $floatFlyDataHolder.data('floatflysettings', data);
        },

        getFieldName: function (name, id) {
            name = name.split('.');
            name = '[' + name.join('][') + ']';

            return 'menu-item-mega[' + id + ']' + name;
        },

        saveChanges: function () {
            var $inputs = sffm.$modal.find('.sffm-content :input'),
                $spinner = sffm.$modal.find('.sffm-toolbar .spinner');

            $inputs.each(function () {
                var $input = $(this);

                if ($input.is(':checkbox') && $input.is(':not(:checked)')) {
                    var $val = $input.val();
                    if ($val == 'on') {
                        $input.attr('value', 'off').prop('checked', true);
                    }
                }
            });

            var data = $inputs.serialize();
            //console.log(data);

            $inputs.filter('[value="off"]').attr('value', 'on').prop('checked', false);

            $spinner.addClass('is-active');
            $.post(ajaxurl, {
                action: 'sffm_save_menu_item_data',
                data: data,
                wp_nonce: sffmMenuData.admin_nonce

            }, function (res) {
                if (!res.success) {
                    return;
                }

                var data = res.data['menu-item-mega'];

                // Update parent menu item
                if (_.has(data, sffm.itemData.data['menu-item-db-id'])) {
                    sffm.setItemData(sffm.itemData.element, data[sffm.itemData.data['menu-item-db-id']]);
                }

                _.each(sffm.itemData.children, function (menuItem) {
                    if (!_.has(data, menuItem.data['menu-item-db-id'])) {
                        return;
                    }

                    sffm.setItemData(menuItem.element, data[menuItem.data['menu-item-db-id']]);
                });

                $spinner.removeClass('is-active');
                sffm.closeModal();
            });
        },

        saveFloatFlyChanges: function () {
            var $inputs = sffm.$modal.find('.sffm-content :input'),
                $spinner = sffm.$modal.find('.sffm-toolbar .spinner');

            $inputs.each(function () {
                var $input = $(this);

                if ($input.is(':checkbox') && $input.is(':not(:checked)')) {
                    var $val = $input.val();
                    if ($val == 'on') {
                        $input.attr('value', 'off').prop('checked', true);
                    }
                }
            });

            var data = $inputs.serialize();
            //console.log(data);

            $inputs.filter('[value="off"]').attr('value', 'on').prop('checked', false);

            $spinner.addClass('is-active');
            $.post(ajaxurl, {
                action: 'sffm_save_floatfly_menu_data',
                data: data,
                menu_type: sffm.floatFlyData.menuType,
                menu_id: sffm.floatFlyData.menuId,
                wp_nonce: sffmMenuData.admin_nonce

            }, function (res) {
                if (!res.success) {
                    return;
                }
                //console.log(res.data);
                sffm.setFloatFlyData(res.data);
                $spinner.removeClass('is-active');
                //sffm.closeModal();
            });
        },

        updateTypographyWeight: function () {
            var value = $(this).val(),
                typographyMain = $(this).closest('.sffm-typography-fields'),
                html = '',
                selected = '',
                typographyWeight = typographyMain.find('.sffm-typography-font-style-field select'),
                sffmVariants = sffmMenuData.sffm_complete_font_variants[value];
            if (sffmVariants) {
                _.each(sffmVariants, function (label, choice) {
                    html += '<option value="' + choice + '"';
                    if (value == 'Default' && choice == 'default') {
                        html += 'selected';
                    } else if (value != 'Default' && choice == '400') {
                        html += 'selected';
                    }
                    html += '>' + label + '</option>';
                })
            }
            typographyWeight.html(html).trigger("chosen:updated");
        },

        activateElementor: function () {
            event.preventDefault();
            var button = $(this);
            button.addClass('updating-message').html(sffmMenuData.activating_text);

            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'sffm_activate_plugin',
                    slug: 'elementor',
                    file: 'elementor'
                },
            }).done(function (result) {
                var result = JSON.parse(result)
                if (result.success) {
                    window.location.href = sffmMenuData.admin_menu_url;
                } else {
                    button.removeClass('updating-message').html(sffmMenuData.error);
                }

            });
        },

        installElementor: function () {
            event.preventDefault();
            var button = $(this);

            button.addClass('updating-message').html(sffmMenuData.installing_text);

            wp.updates.installPlugin({
                slug: 'elementor'
            }).done(function () {
                button.html(sffmMenuData.activating_text);
                $.ajax({
                    url: ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'sffm_activate_plugin',
                        slug: 'elementor',
                        file: 'elementor'
                    },
                }).done(function (result) {
                    var result = JSON.parse(result)
                    if (result.success) {
                        window.location.href = sffmMenuData.admin_menu_url;
                    } else {
                        button.removeClass('updating-message').html(sffmMenuData.error);
                    }

                });
            });
        },

        hideAlert: function (timer) {
            clearTimeout();
            setTimeout(function () {
                if ($('.sffm-alert').hasClass('sffm-alert-active')) {
                    $('.sffm-alert').removeClass('sffm-alert-active');
                    $('.sffm-alert').removeClass('sffm-alert-success sffm-alert-warning sffm-alert-neutral');
                }
            }, timer);
        },

        addSocialIcon: function () {
            var social_icon = '';
            var counter = $('#sffm-add-social-icon').attr('data-count');
            counter++;
            var featureList = '<div class="sffm-social-icon-list">';
            featureList += '<h4>Add Title<span></span></h4>';
            featureList += '<div class="sffm-social-icon-list-wrap" style="display:block">';
            featureList += '<div class="sffm-social-icon-field">';
            featureList += '<label>Icon Select</label>';
            featureList += '<div class="sffm-icon-box-wrap">';
            featureList += '<div class="sffm-selected-icon">';
            featureList += '<i class=""></i>';
            featureList += '<span><i class="sffm-down-icon"></i></span>';
            featureList += '</div>';

            featureList += '<div class="sffm-icon-box">';
            featureList += '<div class="sffm-icon-search">';
            featureList += '<select>';
            featureList += sffm.selectOptionHtml;
            featureList += '</select>';
            featureList += '<input type="text" class="sffm-icon-search-input" placeholder="Type to filter" />';
            featureList += '</div>';
            featureList += sffm.iconHtml;
            featureList += '</div>';
            featureList += '<input class="sffm-icon" type="hidden" value="" name="flymenu_social_icon[' + counter + '][icon]"/>';
            featureList += '</div>';
            featureList += '</div>';
            featureList += '<div class="sffm-social-icon-field"><label>Title</label><input type="text" name="flymenu_social_icon[' + counter + '][icon_name]" ></div>';
            featureList += '<div class="sffm-social-icon-field"><label>Icon URL</label><input type="url" name="flymenu_social_icon[' + counter + '][url]" ></div>';
            featureList += '<div class="sffm-social-icon-field"><label>Icon Tooltip</label><input type="text" name="flymenu_social_icon[' + counter + '][tooltip]" value=""></div>';
            featureList += '<a class="sffm-custom-socialicon-remove" href="#"><i class="sffm-close-icon-2"></i></a>';
            featureList += '</div>';
            featureList += '</div>';

            $('#sffm-social-icon-list').append(featureList);
            $('#sffm-add-social-icon').attr('data-count', counter);
            return false;
        },

        sffmReadFile: function () {
            var input = this;
            if (input.files && input.files[0]) {
                var reader = new FileReader();

                reader.onload = function (e) {
                    var htmlPreview =
                        '<p>' + input.files[0].name + '</p>';
                    var wrapperZone = $(input).parent();
                    var previewZone = $(input).parent().parent().find('.sffm-preview-zone');
                    var boxZone = $(input).parent().parent().find('.sffm-preview-zone').find('.box').find('.box-body');

                    wrapperZone.removeClass('dragover');
                    previewZone.removeClass('hidden');
                    boxZone.empty();
                    boxZone.append(htmlPreview);
                };

                reader.readAsDataURL(input.files[0]);
            }
        },

        sffmDragOverDropzone: function (e) {
            e.preventDefault();
            e.stopPropagation();
            $(this).addClass('dragover');
        },

        sffmDragLeaveDropzone: function (e) {
            e.preventDefault();
            e.stopPropagation();
            $(this).removeClass('dragover');
        },

        sffmRemovePreview: function () {
            var boxZone = $(this).parents('.sffm-preview-zone').find('.box-body');
            var previewZone = $(this).parents('.sffm-preview-zone');
            var dropzone = $(this).parents('.sffm-settings-fields').find('.sffm-dropzone');
            boxZone.empty();
            previewZone.addClass('hidden');
            sffm.reset(dropzone);
        },

        reset: function (e) {
            e.wrap('<form>').closest('form').get(0).reset();
            e.unwrap();
        },

        sffmShowCPTPost: function () {
            var posttype = '#sffm-cpt-' + $(this).data('posttype');
            $(this).is(':checked') ? $(posttype).hide() : $(posttype).show();
        },

        sffmShowHideArchiveList: function () {
            var archivelist = '#sffm-show-archive';
            $(this).is(':checked') ? $(archivelist).hide() : $(archivelist).show();
        },

        importTemplateSetup: function () {
            var template_url = 'https://demo.hashthemes.com/super-floating-and-flying-menu/' + $(this).val().replaceAll('_', '-');
            var template_name = $(this).find(':selected').text();
            $('.sffm_import_template_form #sffm_temp_view_demo').attr('href', template_url);
            $('.sffm_import_template_form #sffm_temp_view_demo span.sffm-temp-name').text(template_name);
            if ($(this).find(':selected').data("elementor")) {
                $('.sffm-require-elementor-notice').removeClass('sffm-hide');
            } else {
                $('.sffm-require-elementor-notice').addClass('sffm-hide');
            }
        },

        select2Search: async function () {
            const selectBox = $(this);
            const selectChoose = $(this).find('select');
            const dataType = selectBox.attr('data-type');
            const dataSelected = selectBox.attr('data-selected');
            await $.post(ajaxurl, {
                action: 'sffm_set_selected_options',
                post_type: dataType,
                selected_ids: dataSelected,
                wp_nonce: sffmMenuData.admin_nonce
            }, function (res) {
                res.results && $.each(res.results, (index, data) => {
                    var newOption = new Option(data.text, data.id, false, true);
                    selectChoose.append(newOption);
                });
            });

            selectChoose.select2({
                placeholder: "Search",
                allowClear: false,
                minimumInputLength: 3,
                dropdownParent: selectChoose.parent('.sffm-settings-fields'),
                ajax: {
                    url: ajaxurl,
                    dataType: 'json',
                    method: 'post',
                    quietMillis: 250,
                    data: function (params) {
                        return {
                            q: params.term,
                            action: 'sffm_get_posts_by_query',
                            post_type: dataType,
                        };
                    },
                    results: function (data) {
                        return {results: data.items};
                    },
                    cache: true
                },
            });
        },

        toggleSubMenuTabs: function () {
            var selected_menu = $(this).data('tab');

            $(this).parent('.sffm-submenu').next('.sffm-submenu-content').find('.sffm-submenu-section').hide();

            // Display The Clicked Tab Content
            $(this).parent('.sffm-submenu').next('.sffm-submenu-content').find('#' + selected_menu).show();

            // Add and remove the class for active tab
            $(this).parent('.sffm-submenu').find('.sffm-submenu-tab').removeClass('sffm-tab-active');
            $(this).addClass('sffm-tab-active');
        }
    };

    $(function () {
        sffm.init();
    });
})(jQuery, _);
