<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://hashthemes.com/
 * @since      1.0.0
 *
 * @package    Super_Floating_Flying_Menu
 * @subpackage Super_Floating_Flying_Menu/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Super_Floating_Flying_Menu
 * @subpackage Super_Floating_Flying_Menu/public
 * @author     Hash Themes 
 */
class Super_Floating_Flying_Menu_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        add_action('wp_head', array($this, 'sffm_menu_add_filter_nav'));
        add_action('wp_footer', array($this, 'sffm_menu'));
        add_action('wp_enqueue_scripts', array($this, 'enqueue_styles'));
        add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'));
        add_filter('sffm_translate_string', array($this, 'sffm_translate_string'), 10, 3);
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {
        wp_enqueue_style('sffm-menuicons', SFFM_URL . 'admin/css/icons/menuicons.css', array(), SFFM_VERSION);
        wp_enqueue_style('sffm-closeicons', SFFM_URL . 'admin/css/icons/closeicons.css', array(), SFFM_VERSION);
        wp_enqueue_style('fontawesome-6.3.0', SFFM_URL . 'admin/css/icons/fontawesome-6.3.0.css', array(), SFFM_VERSION);
        wp_enqueue_style('essentialicon', SFFM_URL . 'admin/css/icons/essentialicon.css', array(), SFFM_VERSION);
        wp_enqueue_style('sffm-eleganticons', SFFM_URL . 'admin/css/icons/eleganticons.css', array(), SFFM_VERSION);
        wp_enqueue_style('iconfont', SFFM_URL . 'admin/css/icons/icofont.css', array(), SFFM_VERSION);
        wp_enqueue_style('materialdesignicons', SFFM_URL . 'admin/css/icons/materialdesignicons.css', array(), SFFM_VERSION);

        if (is_rtl()) {
            wp_enqueue_style('sffm-frontend-floatmenu-style', SFFM_URL . 'public/css/floatmenu-frontend.rtl.css', array(), SFFM_VERSION);
            wp_enqueue_style('sffm-frontend-flymenu-style', SFFM_URL . 'public/css/flymenu-frontend.rtl.css', array(), SFFM_VERSION);
        } else {
            wp_enqueue_style('sffm-frontend-floatmenu-style', SFFM_URL . 'public/css/floatmenu-frontend.css', array(), SFFM_VERSION);
            wp_enqueue_style('sffm-frontend-flymenu-style', SFFM_URL . 'public/css/flymenu-frontend.css', array(), SFFM_VERSION);
        }

        /* Hover CSS */
        wp_enqueue_style('sffm-animate', SFFM_URL . 'public/css/animate.css', array(), SFFM_VERSION);

        /* Animate CSS */
        wp_enqueue_style('sffm-hover', SFFM_URL . 'public/css/hover.css', array(), SFFM_VERSION);

        /* Register Background Videos */
        wp_enqueue_style('jquery-mb-YTPlayer', SFFM_URL . 'public/css/jquery.mb.YTPlayer.min.css', array(), SFFM_VERSION);

        /* Register Custom Scrollbar */
        //wp_enqueue_style('jquery-mCustomScrollbar', SFFM_URL . 'admin/css/jquery.mCustomScrollbar.css', array(), SFFM_VERSION);
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /* Background Videos */
        wp_register_script('sffm-jquery-mb-YTPlayer', SFFM_URL . 'public/js/jquery.mb.YTPlayer.js', array('jquery'), SFFM_VERSION);

        /* Multilevel Menu */
        wp_enqueue_script('modernizr-custom', SFFM_URL . 'public/js/modernizr.custom.js', array(), SFFM_VERSION);
        wp_enqueue_script('jquery-sffm-menu', SFFM_URL . 'public/js/jquery.sffm.menu.js', array('jquery'), SFFM_VERSION, true);

        /* Custom Scrollbar
          wp_enqueue_script('jquery-mCustomScrollbar', SFFM_URL . 'admin/js/jquery.mCustomScrollbar.js', array('jquery'), SFFM_VERSION);
          $sffm_js_obj = array(
          'plugin_url' => WP_PLUGIN_URL,
          );
          wp_localize_script('jquery-mCustomScrollbar', 'sffm_js_obj', $sffm_js_obj);
         */

        wp_enqueue_script('sffm-wave-animation', SFFM_URL . 'public/js/wave-animation.js', array(), SFFM_VERSION, true);
        wp_enqueue_script('sffm-frontend', SFFM_URL . 'public/js/frontend.js', array('jquery', 'jquery-ui-draggable'), SFFM_VERSION, true);
    }

    function sffm_menu_add_filter_nav() {
        $sffm_settings = get_option('sffm_settings');
        if (isset($sffm_settings) && !empty($sffm_settings) && is_array($sffm_settings)) {

            foreach ($sffm_settings as $mkey => $sffm_setting) {
                $default_settings = SFFM_Admin_Templates::default_flyfloat_settings();
                $custom_settings = sffm_recurse_parse_args($sffm_setting, $default_settings);
                $flymenu_settings = $custom_settings['flymenu'];
                $flymenu_toggle_button_settings = $flymenu_settings['toggle_button'];
                $menuid = $sffm_setting['menu_id'];
                add_filter('wp_nav_menu_items', function ($items, $args) use ($flymenu_toggle_button_settings, $menuid) {
                    $menu_html = '';
                    $insert_on_menu = $flymenu_toggle_button_settings['insert_on_menu'];
                    $menu_id = $flymenu_toggle_button_settings['menu'];
                    $menu_icon = $flymenu_toggle_button_settings['menu_icon'];
                    $menu_icon_position = $flymenu_toggle_button_settings['menu_icon_position'];
                    if ($insert_on_menu == 'on' && $menu_icon && $menu_id != 'none') {
                        if (is_object($args->menu) && $args->menu->slug == $menu_id) {
                            $menu_html .= "<li id='sffm-menu-item-trigger-" . $menuid . "' class='menu-item sffm-inline-menu-button'>";
                            $menu_html .= "<a href='#' class='sffm-inline-menu-trigger'>";
                            $menu_html .= "<span class='" . esc_attr($menu_icon) . "' ></span>";
                            $menu_html .= "</a></li>";
                        }

                        if ($menu_icon_position == 'before-menu') {
                            $items = $menu_html . $items;
                        } else {
                            $items = $items . $menu_html;
                        }
                    }
                    return $items;
                }, 10, 2);
            }
        }
    }

    function sffm_menu() {
        if (!(defined('REST_REQUEST') && REST_REQUEST)) {
            $sffm_settings = get_option('sffm_settings');

            if (isset($sffm_settings) && !empty($sffm_settings) && is_array($sffm_settings)) {

                foreach ($sffm_settings as $mkey => $sffm_setting) {
                    if ($this->check_menu_exists($sffm_setting['menu_id']) && $sffm_setting['menu_enabled'] && $sffm_setting['menu_type'] == 'fly_menu') {
                        include SFFM_PATH . 'public/fly-menu/flymenu-front.php';
                    }

                    if ($this->check_menu_exists($sffm_setting['menu_id']) && $sffm_setting['menu_enabled'] && $sffm_setting['menu_type'] == 'floating_menu') {
                        include SFFM_PATH . 'public/floating-menu/floatingmenu-front.php';
                    }
                }
            }
        }
    }

    public static function check_menu_exists($menuid) {
        $menus = get_terms('nav_menu', array('hide_empty' => false, 'parent' => 0));
        if ($menus) {
            $menus = array_combine(wp_list_pluck($menus, 'term_id'), wp_list_pluck($menus, 'name'));

            if (array_key_exists($menuid, $menus)) {
                return true;
            }
        }
    }

    public static function display_condition($specific_page, $hide_show, $front, $blog, $cpt, $error, $search, $archive, $specific_archive) {
        wp_reset_postdata();
        global $post;
        $pageid = is_front_page() ? null : ($post ? $post->ID : null);
        if (class_exists('WooCommerce') && is_shop()) {
            $pageid = wc_get_page_id('shop');
        } elseif (is_single() || is_front_page()) {
            $pageid = isset($post->ID) ? $post->ID : null;
        } elseif (is_archive()) {
            $pageid = get_queried_object_id();
        } elseif (is_home()) {
            $pageid = get_queried_object_id();
        }

        $current_archive = is_front_page() ? 'front' : ($post ? $post->post_type : (get_queried_object() ? get_queried_object()->name : ''));
        $current_post_type = is_archive() ? null : $current_archive;

        $show = true;

        switch ($hide_show) {
            case 'show_all':
                $show = true;
                break;

            case 'hide_all':
                $show = false;
                break;

            case 'show_selected':
                $show = false;
                if (in_array($pageid, $specific_page)) {
                    $show = true;
                }
                if (is_singular() && !is_archive() && in_array($current_post_type, $cpt)) {
                    $show = true;
                }
                if ($front == 'on' && ('front' == $current_archive)) {
                    $show = true;
                }
                if ($blog == 'on' && ('front' == $current_archive)) {
                    $show = true;
                }
                if ($error == 'on' && is_404()) {
                    $show = true;
                }
                if ($search == 'on' && is_search()) {
                    $show = true;
                }
                if ($archive == 'on' && is_archive()) {
                    $show = true;
                }
                if ($archive == 'on' && ('post' == $current_archive && !is_singular())) {
                    $show = true;
                }
                if (!is_singular() && in_array($current_archive, $specific_archive)) {
                    $show = true;
                }
                break;

            case 'hide_selected':
                $show = true;
                if (is_singular() && !is_archive() && in_array($current_post_type, $cpt)) {
                    $show = false;
                }
                if (in_array($pageid, $specific_page)) {
                    $show = false;
                }
                if ($front == 'on' && ('front' == $current_archive)) {
                    $show = false;
                }
                if ($blog == 'on' && ('front' == $current_archive)) {
                    $show = false;
                }
                if ($error == 'on' && is_404()) {
                    $show = false;
                }
                if ($search == 'on' && is_search()) {
                    $show = false;
                }
                if ($archive == 'on' && ('post' == $current_archive && !is_singular())) {
                    $show = false;
                }
                if (!is_singular() && in_array($current_archive, $specific_archive)) {
                    $show = false;
                }
                break;
        }
        return $show;
    }

    public static function display_polylang_condition($polylang_display_condition, $polylang_show_languages) {
        $show = true;

        if (function_exists('pll_current_language')) {
            $pll_current_language = pll_current_language('slug');

            switch ($polylang_display_condition) {
                case 'show_all':
                    $show = true;
                    break;

                case 'show_selected':
                    $show = false;
                    if (in_array($pll_current_language, $polylang_show_languages)) {
                        $show = true;
                    }
                    break;

                case 'hide_selected':
                    $show = true;
                    if (in_array($pll_current_language, $polylang_show_languages)) {
                        $show = false;
                    }
                    break;
            }
        }

        return $show;
    }

    public function is_standard_font($font) {
        $standard_fonts = ['Default', 'Helvetica', 'Verdana', 'Arial', 'Times', 'Georgia', 'Courier', 'Trebuchet', 'Tahoma', 'Palatino'];
        if (in_array($font, $standard_fonts)) {
            $flag = 'standard';
        } else {
            $flag = 'google';
        }
        return $flag;
    }

    public static function get_image_alt_by_url($url = '') {
        $image_id = attachment_url_to_postid($url);
        if ($image_id) {
            $image_alt = get_post_meta($image_id, '_wp_attachment_image_alt', TRUE);
            if ($image_alt) {
                return ' alt="' . $image_alt . '"';
            }
        }
    }

    public function sffm_translate_string($original_value, $domain, $name = '') {
        $wpml_translation = apply_filters('wpml_translate_single_string', $original_value, $domain, $name);
        if ($wpml_translation === $original_value && function_exists('pll__')) {
            return pll__($original_value);
        }
        return $wpml_translation;
    }

    public static function css_strip_whitespace($css) {
        $replace = array(
            "#/\*.*?\*/#s" => "", // Strip C style comments.
            "#\s\s+#" => " ", // Strip excess whitespace.
        );
        $search = array_keys($replace);
        $css = preg_replace($search, $replace, $css);

        $replace = array(
            ": " => ":",
            "; " => ";",
            " {" => "{",
            " }" => "}",
            ", " => ",",
            "{ " => "{",
            ";}" => "}", // Strip optional semicolons.
            ",\n" => ",", // Don't wrap multiple selectors.
            "\n}" => "}", // Don't wrap closing braces.
            //"}" => "}\n", // Put each rule on it's own line.
        );
        $search = array_keys($replace);
        $css = str_replace($search, $replace, $css);

        return trim($css);
    }

}
