/**
 * jquery.sffmmenu.js v1.0.1
 * http://www.codrops.com
 *
 * Licensed under the MIT license.
 * http://www.opensource.org/licenses/mit-license.php
 *
 * Copyright 2013, Codrops
 * http://www.codrops.com
 */
;
(function ($, window, undefined) {

    'use strict';

    // global
    var Modernizr = window.Modernizr, $body = $('body');

    $.SFFMMenu = function (options, element) {
        this.$el = $(element);
        this._init(options);
    };

    // the options
    $.SFFMMenu.defaults = {
        // classes for the animation effects
        animationClasses: {classin: 'sffm-animate-in-1', classout: 'sffm-animate-out-1'},
        // callback: click a link that has a sub menu
        // el is the link element (li); name is the level name
        onLevelClick: function (el, name) {
            return false;
        },
        // callback: click a link that does not have a sub menu
        // el is the link element (li); ev is the event obj
        onLinkClick: function (el, ev) {
            return false;
        }
    };

    $.SFFMMenu.prototype = {
        _init: function (options) {

            // options
            this.options = $.extend(true, {}, $.SFFMMenu.defaults, options);
            // cache some elements and initialize some variables
            this._config();

            var animEndEventNames = {
                'WebkitAnimation': 'webkitAnimationEnd',
                'OAnimation': 'oAnimationEnd',
                'msAnimation': 'MSAnimationEnd',
                'animation': 'animationend'
            };
            // animation end event name
            this.animEndEventName = animEndEventNames[Modernizr.prefixed('animation')] + '.sffm-menu';
            // support for css animations and css transitions
            this.supportAnimations = Modernizr.cssanimations;

            this._initEvents();

        },
        _config: function () {
            this.$wrap = this.$el.closest('.sffm-flymenu-wrapper');
            this.$trigger = this.$wrap.find('.sffm-flymenu-trigger');
            this.$menu = this.$el.children('ul.sffm-menu');
            this.$menuitems = this.$menu.find('li:not(.sffm-back)');
            this.$back = this.$menu.find('li.sffm-back');
        },
        _initEvents: function () {

            var self = this;

            self._addHeight();
            this.$wrap.addClass('sffm-submenu-animate-loaded');

            if (this.$menu.closest('.sffm-flymenu-wrapper').hasClass('sffm-parent-menu-click-enable')) {
                this.$menu.find('li:not(.sffm-back) .sffm-submenu-toggle').on('click', function (event) {

                    event.stopPropagation();
                    var $item = $(this).closest('li'),
                        $submenu = $item.children('ul.sffm-submenu');

                    // Only go to the next menu level if one exists AND the link isn't the
                    // one we added specifically for navigating to parent item pages.
                    if (($submenu.length > 0) && !($(event.currentTarget).hasClass('sffm-subviewopen'))) {

                        var $flyin = $submenu.clone().css('opacity', 0).insertAfter(self.$menu);

                        /*NEWCODE*/
                        var height = $($flyin).height();
                        $($submenu).closest('.sffm-menu-container').height(height);

                        var onAnimationEndFn = function () {
                            self.$menu.off(self.animEndEventName).removeClass(self.options.animationClasses.classout).addClass('sffm-subview');
                            $item.addClass('sffm-subviewopen').parents('.sffm-subviewopen:first').removeClass('sffm-subviewopen').addClass('sffm-subview');
                            $flyin.remove();
                        };

                        setTimeout(function () {
                            $flyin.addClass(self.options.animationClasses.classin);
                            self.$menu.addClass(self.options.animationClasses.classout);
                            if (self.supportAnimations) {
                                self.$menu.on(self.animEndEventName, onAnimationEndFn);
                            } else {
                                onAnimationEndFn.call();
                            }

                            self.options.onLevelClick($item, $item.children('a:first').text());
                        });

                        return false;

                    } else {
                        self.options.onLinkClick($item, event);
                    }

                });

            } else {
                this.$menuitems.on('click', function (event) {

                    event.stopPropagation();
                    var $item = $(this),
                        $submenu = $item.children('ul.sffm-submenu');

                    // Only go to the next menu level if one exists AND the link isn't the
                    // one we added specifically for navigating to parent item pages.
                    if (($submenu.length > 0) && !($(event.currentTarget).hasClass('sffm-subviewopen'))) {

                        var $flyin = $submenu.clone().css('opacity', 0).insertAfter(self.$menu);

                        /*NEWCODE*/
                        var height = $($flyin).height();
                        $($submenu).closest('.sffm-menu-container').height(height);

                        var onAnimationEndFn = function () {
                            self.$menu.off(self.animEndEventName).removeClass(self.options.animationClasses.classout).addClass('sffm-subview');
                            $item.addClass('sffm-subviewopen').parents('.sffm-subviewopen:first').removeClass('sffm-subviewopen').addClass('sffm-subview');
                            $flyin.remove();
                        };

                        setTimeout(function () {
                            $flyin.addClass(self.options.animationClasses.classin);
                            self.$menu.addClass(self.options.animationClasses.classout);
                            if (self.supportAnimations) {
                                self.$menu.on(self.animEndEventName, onAnimationEndFn);
                            } else {
                                onAnimationEndFn.call();
                            }

                            self.options.onLevelClick($item, $item.children('a:first').text());
                        });

                        return false;

                    } else {
                        self.options.onLinkClick($item, event);
                    }

                });
            }

            this.$back.on('click', function (event) {

                var $this = $(this),
                    $submenu = $this.parents('ul.sffm-submenu:first'),
                    $item = $submenu.parent(),
                    $parent = $item.parent('ul'),
                    $flyin = $submenu.clone().insertAfter(self.$menu);


                var $clonedEle = $($parent).clone().css({visibility: "hidden", display: "block", position: "absolute", margin: 0, padding: 0}).removeClass('sffm-subview');
                $submenu.closest('.sffm-menu-container').append($clonedEle).find('.sffm-subviewopen').removeClass('sffm-subviewopen');
                /*NEWCODE*/
                $submenu.closest('.sffm-menu-container').outerHeight($clonedEle.height());

                $clonedEle.remove();


                var onAnimationEndFn = function () {
                    self.$menu.off(self.animEndEventName).removeClass(self.options.animationClasses.classin);
                    $flyin.remove();
                };

                setTimeout(function () {
                    $flyin.addClass(self.options.animationClasses.classout);
                    self.$menu.addClass(self.options.animationClasses.classin);

                    if (self.supportAnimations) {
                        self.$menu.on(self.animEndEventName, onAnimationEndFn);
                    } else {
                        onAnimationEndFn.call();
                    }

                    $item.removeClass('sffm-subviewopen');

                    var $subview = $this.parents('.sffm-subview:first');
                    if ($subview.is('li')) {
                        $subview.addClass('sffm-subviewopen');
                    }
                    $subview.removeClass('sffm-subview');
                });

                return false;

            });

            $(document).on('click', this.$trigger, function (event) {
                self._addHeight();
            });

        },
        _addHeight: function () {
            this.$el.height(this.$menu.height());
        }
    };

    var logError = function (message) {
        if (window.console) {
            window.console.error(message);
        }
    };

    $.fn.sffmmenu = function (options) {
        if (typeof options === 'string') {
            var args = Array.prototype.slice.call(arguments, 1);
            this.each(function () {
                var instance = $.data(this, 'sffmmenu');
                if (!instance) {
                    logError("cannot call methods on sffmmenu prior to initialization; " +
                        "attempted to call method '" + options + "'");
                    return;
                }
                if (!$.isFunction(instance[options]) || options.charAt(0) === "_") {
                    logError("no such method '" + options + "' for sffmmenu instance");
                    return;
                }
                instance[options].apply(instance, args);
            });
        } else {
            this.each(function () {
                var instance = $.data(this, 'sffmmenu');
                if (instance) {
                    instance._init();
                } else {
                    instance = $.data(this, 'sffmmenu', new $.SFFMMenu(options, this));
                }
            });
        }
        return this;
    };

})(jQuery, window);