<?php

defined('ABSPATH') or die('No script kiddies please!');

if (!class_exists('SFFM_Floatingmenu_Walker_Class')) {


    class SFFM_Floatingmenu_Walker_Class extends Walker_Nav_Menu {

        private $counter = 0;

        function start_el(&$output, $menu_item, $depth = 0, $args = array(), $current_object_id = 0) {
            if (isset($args->item_spacing) && 'discard' === $args->item_spacing) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            $indent = ($depth) ? str_repeat($t, $depth) : '';

            $counter = $this->counter;
            $counter++;
            $this->counter = $counter;

            if (is_string($args->menu)) {
                $menuid = $args->menu;
            } elseif (is_object($args->menu)) {
                $menuid = $args->menu->term_id;
            }
            $menukey = 'menu_' . $menuid;

            $sffm_settings = get_option('sffm_settings');
            $sffm_setting = $sffm_settings[$menukey];
            $default_settings = SFFM_Admin_Templates::default_flyfloat_settings();
            $custom_settings = sffm_recurse_parse_args($sffm_setting, $default_settings);
            $floatmenu_settings = $custom_settings['floatmenu'];
            $template = isset($floatmenu_settings['template']) ? $floatmenu_settings['template'] : 'floatmenu-template-1';

            if ((in_array($template, ['floatmenu-template-7', 'floatmenu-template-8', 'floatmenu-template-9'])) && $counter > 16) {
                return;
            } elseif (($template == 'floatmenu-template-10') && $counter > 18) {
                return;
            }

            $sffm_item_settings = get_post_meta($menu_item->ID, 'sffm_item_settings', true);
            $sffm_default_settings = SFFM_Admin_Templates::default_settings();
            $sffm_item_settings = wp_parse_args($sffm_item_settings, $sffm_default_settings);

            $tooltip_enable = $sffm_item_settings['floatingmenu']['tooltip_enable'];
            $tooltip_text = apply_filters('sffm_translate_string', $sffm_item_settings['floatingmenu']['tooltip_text'], 'Super Floating and Flying Menu', 'Menu Item Tooltip Text');
            $icon_type = $sffm_item_settings['floatingmenu']['icon_type'];
            $available_icon = $sffm_item_settings['floatingmenu']['available_icon'];
            $img_icon = $sffm_item_settings['floatingmenu']['img_icon'];
            $openin_newtab = $sffm_item_settings['floatingmenu']['target_blank'];
            $action = $sffm_item_settings['floatingmenu']['action'];
            $sectionid = $sffm_item_settings['floatingmenu']['scroll_sectionid'];

            $classes = array();
            $classes[] = isset($menu_item->classes[0]) ? $menu_item->classes[0] : '';
            $classes[] = 'sffm-menu-item-' . esc_attr($menu_item->ID);
            $classes[] = $menu_item->current ? 'sffm-active' : '';
            $classes[] = 'sffm-menu-no-' . esc_attr($counter) . ' sffm-menu-items';

            $args = apply_filters('sffm_nav_menu_item_args', $args, $menu_item, $depth);

            $class_names = implode(' ', apply_filters('sffm_nav_menu_css_class', array_filter($classes), $menu_item, $args, $depth));
            $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

            $id = apply_filters('sffm_nav_menu_item_id', 'sffm-menu-item-' . $menu_item->ID, $menu_item, $args, $depth);
            $id = $id ? ' id="' . esc_attr($id) . '"' : '';

            $output .= $indent . '<li' . $id . $class_names . '>';

            $atts = array();
            $atts['title'] = !empty($menu_item->attr_title) ? $menu_item->attr_title : '';

            if ($action == 'default') {
                $atts['target'] = $openin_newtab == 'on' ? '_blank' : '_self';
                if ('_blank' === $atts['target'] && empty($menu_item->xfn)) {
                    $atts['rel'] = 'noopener';
                } else {
                    $atts['rel'] = $menu_item->xfn;
                }
                $atts['href'] = !empty($menu_item->url) ? $menu_item->url : '';
            } elseif ($action == 'scroll_sectionid') {
                $atts['data-sectionid'] = !empty($sectionid) ? esc_attr($sectionid) : '#';
                $atts['class'] = 'sffm-scroll-nav-tab sffm-scroll-sectionid';
                $atts['href'] = '#';
            }

            $atts = apply_filters('sffm_nav_menu_link_attributes', $atts, $menu_item, $args, $depth);

            $attributes = '';
            foreach ($atts as $attr => $value) {
                if (is_scalar($value) && '' !== $value && false !== $value) {
                    $value = ('href' === $attr) ? esc_url($value) : esc_attr($value);
                    $attributes .= ' ' . $attr . '="' . $value . '"';
                }
            }

            $item_output = $args->before;

            $item_output .= '<a' . $attributes . '>';

            /* Menu Icon */
            switch ($icon_type) {
                case 'available_icon':
                    if (isset($available_icon) && !empty($available_icon)) {
                        $item_output .= '<i class="sffm-icon ' . esc_attr($available_icon) . '"></i>';
                    }
                    break;
                case 'custom_icon':
                    if ($img_icon) {
                        $item_output .= '<img src="' . esc_url($img_icon) . '"' . Super_Floating_Flying_Menu_Public::get_image_alt_by_url($img_icon) . '/>';
                    }
                    break;
            }

            $item_output .= '</a>';

            /* Tooltip */
            if ($tooltip_enable == 'on') {
                $item_output .= '<span class="sffm-tooltip">';
                $item_output .= '<a class="sffm-tooltip-link"' . $attributes . '>';
                $item_output .= !empty($tooltip_text) ? esc_html($tooltip_text) : esc_html(apply_filters('the_title', $menu_item->title, $menu_item->ID));
                $item_output .= '</a>';
                $item_output .= '</span>';
            }

            $item_output .= $args->after;

            $output .= apply_filters('sffm_walker_nav_menu_start_el', $item_output, $menu_item, $depth, $args);
        }

    }

}