<?php

defined('ABSPATH') or die('No script kiddies please!');

if (!class_exists('SFFM_Fullscreen_Walker_Class')) {


    class SFFM_Fullscreen_Walker_Class extends Walker_Nav_Menu {

        public function start_lvl(&$output, $depth = 0, $args = array()) {
            if (isset($args->item_spacing) && 'discard' === $args->item_spacing) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            $indent = str_repeat($t, $depth);

            if (is_string($args->menu)) {
                $menuid = $args->menu;
            } elseif (is_object($args->menu)) {
                $menuid = $args->menu->term_id;
            }
            $menukey = 'menu_' . $menuid;

            $sffm_settings = get_option('sffm_settings');
            $sffm_setting = $sffm_settings[$menukey];
            $default_settings = SFFM_Admin_Templates::default_flyfloat_settings();
            $custom_settings = sffm_recurse_parse_args($sffm_setting, $default_settings);
            $flymenu_settings = $custom_settings['flymenu'];
            $classes = array('sffm-submenu');

            $submenu_animation = $flymenu_settings['fullscreen_menu_submenu_animation'];

            $class_names = implode(' ', apply_filters('sffm_nav_menu_submenu_css_class', $classes, $args, $depth));
            $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

            $output .= "{$n}{$indent}<ul$class_names>{$n}";

            if (in_array($submenu_animation, ['flip', 'translate-x', 'zoom-out', 'zoom-in', 'translate-y'])) {
                $output .= "{$n}{$indent}<li class='sffm-back sffm-menu-item'><a class='sffm-menu-item-link' href='#'><i class='mdi mdi-chevron-left'></i>" . esc_html__('Back', 'super-floating-flying-menu') . "</a></li>{$n}";
            }
        }

        public function end_lvl(&$output, $depth = 0, $args = null) {
            if (isset($args->item_spacing) && 'discard' === $args->item_spacing) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            $indent = str_repeat($t, $depth);

            $output .= "$indent</ul>{$n}";
        }

        function start_el(&$output, $menu_item, $depth = 0, $args = array(), $id = 0) {

            if (isset($args->item_spacing) && 'discard' === $args->item_spacing) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            $indent = ($depth) ? str_repeat($t, $depth) : '';

            if (is_string($args->menu)) {
                $menuid = $args->menu;
            } elseif (is_object($args->menu)) {
                $menuid = $args->menu->term_id;
            }
            $menukey = 'menu_' . $menuid;

            $sffm_settings = get_option('sffm_settings');
            $sffm_setting = $sffm_settings[$menukey];
            $default_settings = SFFM_Admin_Templates::default_flyfloat_settings();
            $custom_settings = sffm_recurse_parse_args($sffm_setting, $default_settings);
            $flymenu_settings = $custom_settings['flymenu'];
            $submenu_toggle_open_icon = $flymenu_settings['submenu_toggle_open_icon'];
            $submenu_toggle_close_icon = $flymenu_settings['submenu_toggle_close_icon'];

            /* Get menu items settings */
            $sffm_item_old_settings = get_post_meta($menu_item->ID, 'sffm_item_settings', true);
            $sffm_default_settings = SFFM_Admin_Templates::default_settings();
            $sffm_item_settings = sffm_recurse_parse_args($sffm_item_old_settings, $sffm_default_settings);

            $short_description = apply_filters('sffm_translate_string', $sffm_item_settings['flymenu']['short_description'], 'Super Floating and Flying Menu', 'Menu Item Short Description');
            $additional_content = apply_filters('sffm_translate_string', $sffm_item_settings['flymenu']['additional_content'], 'Super Floating and Flying Menu', 'Menu Item Additional Content');
            $notification_label = apply_filters('sffm_translate_string', $sffm_item_settings['flymenu']['notification_label'], 'Super Floating and Flying Menu', 'Menu Item Notification Label');
            $icon_type = $sffm_item_settings['flymenu']['icon_type'];
            $available_icon = $sffm_item_settings['flymenu']['available_icon'];
            $img_icon = $sffm_item_settings['flymenu']['img_icon'];

            $classes = array('sffm-menu-item');
            $classes[] = isset($menu_item->classes[0]) ? $menu_item->classes[0] : '';
            $classes[] = 'sffm-menu-item-' . esc_attr($menu_item->ID);
            $classes[] = $args->walker->has_children ? 'sffm-menu-item-has-children' : '';
            $classes[] = $menu_item->current ? 'sffm-active' : '';
            if (in_array('current-menu-parent', $menu_item->classes)) {
                $classes[] = 'sffm-current-menu-parent';
            }

            $args = apply_filters('sffm_nav_menu_item_args', $args, $menu_item, $depth);

            $class_names = implode(' ', apply_filters('sffm_nav_menu_css_class', array_filter($classes), $menu_item, $args, $depth));
            $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

            $id = apply_filters('sffm_nav_menu_item_id', 'sffm-menu-item-' . $menu_item->ID, $menu_item, $args, $depth);
            $id = $id ? ' id="' . esc_attr($id) . '"' : '';

            $output .= $indent . '<li' . $id . $class_names . '>';

            $atts = array();
            $atts['class'] = 'sffm-menu-item-link sffm-menu-item-link-depth-' . $depth . (($args->walker->has_children || !empty($additional_content)) ? ' sffm-menu-item-link-has-children' : '');
            $atts['title'] = !empty($menu_item->attr_title) ? $menu_item->attr_title : '';
            $atts['target'] = !empty($menu_item->target) ? $menu_item->target : '';
            if ('_blank' === $atts['target'] && empty($menu_item->xfn)) {
                $atts['rel'] = 'noopener';
            } else {
                $atts['rel'] = $menu_item->xfn;
            }

            $atts['href'] = !empty($menu_item->url) ? $menu_item->url : '';

            $atts = apply_filters('sffm_nav_menu_link_attributes', $atts, $menu_item, $args, $depth);

            $attributes = '';
            foreach ($atts as $attr => $value) {
                if (is_scalar($value) && '' !== $value && false !== $value) {
                    $value = ('href' === $attr) ? esc_url($value) : esc_attr($value);
                    $attributes .= ' ' . $attr . '="' . $value . '"';
                }
            }

            $item_output = $args->before;

            $item_output .= '<a' . $attributes . '>';

            $item_output .= '<span class="sffm-menu-link-items">';
            $item_output .= '<span class="sffm-menu-item-title">';
            /* Menu Icon */
            switch ($icon_type) {
                case 'available_icon':
                    if (isset($available_icon) && !empty($available_icon)) {
                        $item_output .= '<i class="sffm-menu-icon ' . esc_attr($available_icon) . '"></i>';
                    }
                    break;
                case 'custom_icon':
                    if ($img_icon) {
                        $item_output .= '<img src = "' . esc_url($img_icon) . '"' . Super_Floating_Flying_Menu_Public::get_image_alt_by_url($img_icon) . '/>';
                    }
                    break;
            }
            $item_output .= esc_html(apply_filters('the_title', $menu_item->title, $menu_item->ID));

            /* Notification Label */
            if (!empty($notification_label)) {
                $item_output .= '<span class="sffm-menu-item-notification-label">' . esc_html($notification_label) . '</span>';
            }

            $item_output .= '</span>';

            if ($args->walker->has_children) {
                $item_output .= '<span class="sffm-submenu-toggle">';
                $item_output .= '<i class="sffm-submenu-open-icon ' . esc_attr($submenu_toggle_open_icon) . '"></i>';
                $item_output .= '<i class="sffm-submenu-close-icon ' . esc_attr($submenu_toggle_close_icon) . '"></i>';
                $item_output .= '</span>';
            }
            $item_output .= '</span>';

            /* Short Description */
            if (!empty($short_description)) {
                $item_output .= '<span class="sffm-menu-item-description">' . esc_html($short_description) . '</span>';
            }

            $item_output .= '</a>';

            if ($depth > 0 && !empty($additional_content)) {
                $item_output .= '<div class="sffm-addditional-content">';
                $item_output .= do_shortcode(wpautop(wp_kses_post($additional_content)));
                $item_output .= '</div>';
            }

            $item_output .= $args->after;

            $output .= apply_filters('sffm_walker_nav_menu_start_el', $item_output, $menu_item, $depth, $args);
        }

    }

}