<?php

defined('ABSPATH') or die('No script kiddies please!');

if (!class_exists('SFFM_Navindicator_Walker_Class')) {


    class SFFM_Navindicator_Walker_Class extends Walker_Nav_Menu {

        function start_el(&$output, $menu_item, $depth = 0, $args = array(), $current_object_id = 0) {
            if (isset($args->item_spacing) && 'discard' === $args->item_spacing) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            $indent = ($depth) ? str_repeat($t, $depth) : '';

            if (is_string($args->menu)) {
                $menuid = $args->menu;
            } elseif (is_object($args->menu)) {
                $menuid = $args->menu->term_id;
            }
            $menukey = 'menu_' . $menuid;

            $sffm_settings = get_option('sffm_settings');
            $sffm_setting = $sffm_settings[$menukey];
            $default_settings = SFFM_Admin_Templates::default_flyfloat_settings();
            $custom_settings = sffm_recurse_parse_args($sffm_setting, $default_settings);
            $floatmenu_settings = $custom_settings['floatmenu'];
            $animation = $floatmenu_settings['temp_14_animation'];

            $sffm_item_settings = get_post_meta($menu_item->ID, 'sffm_item_settings', true);
            $sffm_default_settings = SFFM_Admin_Templates::default_settings();
            $sffm_item_settings = wp_parse_args($sffm_item_settings, $sffm_default_settings);

            $tooltip_text = apply_filters('sffm_translate_string', $sffm_item_settings['floatingmenu']['tooltip_text'], 'Super Floating and Flying Menu', 'Menu Item Tooltip Text');
            $openin_newtab = $sffm_item_settings['floatingmenu']['target_blank'];
            $action = $sffm_item_settings['floatingmenu']['action'];
            $sectionid = $sffm_item_settings['floatingmenu']['scroll_sectionid'];

            $classes = array();
            $classes[] = isset($menu_item->classes[0]) ? $menu_item->classes[0] : '';
            $classes[] = 'sffm-menu-item-' . esc_attr($menu_item->ID);

            $args = apply_filters('sffm_nav_menu_item_args', $args, $menu_item, $depth);

            $class_names = implode(' ', apply_filters('sffm_nav_menu_css_class', array_filter($classes), $menu_item, $args, $depth));
            $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

            $id = apply_filters('sffm_nav_menu_item_id', 'sffm-menu-item-' . $menu_item->ID, $menu_item, $args, $depth);
            $id = $id ? ' id="' . esc_attr($id) . '"' : '';

            $output .= $indent . '<li' . $id . $class_names . '>';

            $atts = array();
            $atts['title'] = !empty($menu_item->attr_title) ? $menu_item->attr_title : '';

            if ($action == 'default') {
                $atts['target'] = $openin_newtab == 'on' ? '_blank' : '_self';
                if ('_blank' === $atts['target'] && empty($menu_item->xfn)) {
                    $atts['rel'] = 'noopener';
                } else {
                    $atts['rel'] = $menu_item->xfn;
                }
                $atts['href'] = !empty($menu_item->url) ? $menu_item->url : '';
                $atts['class'] = $menu_item->current ? 'sffm-scrollsection-active' : '';
            } elseif ($action == 'scroll_sectionid') {
                $atts['data-sectionid'] = !empty($sectionid) ? esc_attr($sectionid) : '#';
                $atts['class'] = 'sffm-scroll-nav-tab sffm-scroll-sectionid';
                $atts['href'] = '#';
            }

            $atts = apply_filters('sffm_nav_menu_link_attributes', $atts, $menu_item, $args, $depth);

            $attributes = '';
            foreach ($atts as $attr => $value) {
                if (is_scalar($value) && '' !== $value && false !== $value) {
                    $value = ('href' === $attr) ? esc_url($value) : esc_attr($value);
                    $attributes .= ' ' . $attr . '="' . $value . '"';
                }
            }

            $item_output = $args->before;

            $item_output .= '<a' . $attributes . '>';

            if ($animation == 'animation-8')
                $item_output .= '<svg class="sffm-svg-icon" viewBox="0 0 24 24"><path d="M17.6,2.9L17.6,2.9c-3.1-3.1-8.2-3.1-11.3,0l0,0C3.6,5.7,3.2,11,5.6,14.2l6.4,9.2l6.4-9.2C20.8,11,20.4,5.7,17.6,2.9z M12.1,11.1c-1.5,0-2.6-1.2-2.6-2.6s1.2-2.6,2.6-2.6s2.6,1.2,2.6,2.6S13.5,11.1,12.1,11.1z" /></svg>';

            if ($animation == 'animation-6')
                $item_output .= '<svg class="sffm-svg-icon" viewBox="0 0 16 16"><circle cx="8" cy="8" r="6.215"></circle></svg>';

            if ($animation == 'animation-12')
                $item_output .= '<svg class="sffm-svg-icon" viewBox="0 0 24 24"><path d="M4.5,19.8C4.5,19.8,4.5,19.8,4.5,19.8V4.2c0-0.3,0.2-0.5,0.4-0.7c0.2-0.1,0.5-0.1,0.8,0l13.5,7.8c0.2,0.1,0.4,0.4,0.4,0.7c0,0.3-0.2,0.5-0.4,0.7L5.7,20.4c-0.1,0.1-0.3,0.1-0.5,0.1C4.8,20.6,4.5,20.2,4.5,19.8z M6,5.6v12.8L17.2,12L6,5.6z"/></svg>';

            /* Tooltip */
            $item_output .= '<span class="sffm-tooltip">';
            if ($animation == 'animation-4') {
                $item_output .= '<svg class="sffm-svg-icon" viewBox="0 0 19 12.93"><g><g><path d="M19,7.13H11.48c-.2,0-.3.1-.5.1l-9.4,4.3a45.7,45.7,0,0,0,4.7-3.7c.1-.2-.1-.4-.2-.5a.76.76,0,0,0-.5-.2h-.5a2.43,2.43,0,0,1-2.4-2.4V0H1.18V4.63c0,2.2,1,3.5,3.2,3.5a31.36,31.36,0,0,0-4.3,3.8c-.2.2,0,.8.2.9a.37.37,0,0,0,.3.1c.2,0,.3-.1.5-.1l10.7-4.1H19Z"/></g></g></svg>';
            }
            $item_output .= !empty($tooltip_text) ? esc_html($tooltip_text) : esc_html(apply_filters('the_title', $menu_item->title, $menu_item->ID));
            $item_output .= '</span>';

            $item_output .= '</a>';

            $item_output .= $args->after;

            $output .= apply_filters('sffm_walker_nav_menu_start_el', $item_output, $menu_item, $depth, $args);
        }

    }

}